@@ -61,7 +61,7 @@ QString KCategoryReassignDlg::show(const MyMoneyAccount& category)
     QStringList list;
     QStringList::const_iterator it_a;
     ui->m_category->selector()->itemList(list);
-    for (it_a = list.constBegin(); it_a != list.constEnd(); ++it_a) {
+    for (it_a = list.cbegin(); it_a != list.cend(); ++it_a) {
         MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
         if (acc.currencyId() != category.currencyId())
             ui->m_category->selector()->removeItem(*it_a);
@@ -72,7 +72,7 @@ QString KCategoryReassignDlg::show(const MyMoneyAccount& category)
 
     // if there is no category for reassignment left, we bail out
     if (list.isEmpty()) {
-        KMessageBox::sorry(this, QString("<qt>") + i18n("At least one transaction/schedule still references the category <b>%1</b>.  However, at least one category with the same currency must exist so that the transactions/schedules can be reassigned.", category.name()) + QString("</qt>"));
+        KMessageBox::error(this, QString("<qt>") + i18n("At least one transaction/schedule still references the category <b>%1</b>.  However, at least one category with the same currency must exist so that the transactions/schedules can be reassigned.", category.name()) + QString("</qt>"));
         return QString();
     }
 
