@@ -7,6 +7,8 @@
 #ifndef KCURRENCYEDITORDLG_H
 #define KCURRENCYEDITORDLG_H
 
+#include "kmm_base_dialogs_export.h"
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -25,7 +27,7 @@ class KCurrencyEditorDlg;
 
 class MyMoneySecurity;
 class KCurrencyEditorDlgPrivate;
-class KCurrencyEditorDlg : public QDialog
+class KMM_BASE_DIALOGS_EXPORT KCurrencyEditorDlg : public QDialog
 {
     Q_DISABLE_COPY(KCurrencyEditorDlg)
 
