@@ -28,7 +28,7 @@ using namespace eMyMoney;
 class SpecialLedgerItemFilterPrivate : public LedgerSortProxyModelPrivate
 {
     struct BalanceParameter {
-        Qt::SortOrder sortOrder;
+        Qt::SortOrder sortOrder = Qt::AscendingOrder;
         int startRow = 0;
         int lastRow = 0;
         int firstRow = 0;
@@ -54,7 +54,7 @@ public:
         , lastWasReconciliationEntry(false)
     {
         updateDelayTimer.setSingleShot(true);
-        updateDelayTimer.setInterval(20);
+        updateDelayTimer.setInterval(100);
     }
 
     bool isSortingByDateFirst() const
@@ -127,7 +127,8 @@ public:
      * simplifies the calculation of the balance.
      *
      * @Note One must pay attention to use @c qAbs(x) when creating the QModelIndex
-     * to access the data.
+     * to access the data. Please keep in mind that the actual balance calculation
+     * is performed on the source model.
      */
     BalanceParameter initializeBalanceCalculation() const
     {
@@ -135,14 +136,14 @@ public:
         // we only display balances when sorted by a date field
         const auto order = sourceModel->ledgerSortOrder();
         if (isSortingByDate()) {
-            const auto rows = q->rowCount();
+            const auto rows = sourceModel->rowCount();
             if (rows > 0) {
                 parameter.sortOrder = order.first().sortOrder;
                 parameter.startRow = (parameter.sortOrder == Qt::AscendingOrder) ? 0 : -(rows - 1);
                 parameter.lastRow = (parameter.sortOrder == Qt::AscendingOrder) ? rows - 1 : 0;
 
                 for (int row = parameter.startRow; (row >= parameter.startRow) && (row <= parameter.lastRow); ++row) {
-                    const auto idx = q->index(qAbs(row), 0);
+                    const auto idx = sourceModel->index(qAbs(row), 0);
                     if (isJournalModel(idx) || isSchedulesJournalModel(idx)) {
                         parameter.setFirstRow(row);
                         break;
@@ -153,6 +154,11 @@ public:
         return parameter;
     }
 
+    /**
+     * Recalculate the balances.
+     *
+     * @note Please keep in mind that the actual balance calculation is performed on the source model.
+     */
     void recalculateBalances()
     {
         QMap<QString, MyMoneyMoney> balances;
@@ -160,7 +166,7 @@ public:
         const auto parameter = initializeBalanceCalculation();
 
         if (parameter.isValid()) {
-            auto idx = q->index(qAbs(parameter.firstRow), 0);
+            auto idx = sourceModel->index(qAbs(parameter.firstRow), 0);
             const MyMoneyMoney showValuesInverted = idx.data(eMyMoney::Model::ShowValueInvertedRole).toBool() ? MyMoneyMoney::MINUS_ONE : MyMoneyMoney::ONE;
             auto accountId = idx.data(eMyMoney::Model::JournalSplitAccountIdRole).toString();
             const auto account = MyMoneyFile::instance()->accountsModel()->itemById(accountId);
@@ -171,7 +177,7 @@ public:
                 // if sorted by entry date or by security, we need to find the balance of the oldest
                 // transaction in the set. This may not be the date of the first transaction displayed
                 for (int row = parameter.firstRow; (row >= parameter.startRow) && (row <= parameter.lastRow); ++row) {
-                    idx = q->index(qAbs(row), 0);
+                    idx = sourceModel->index(qAbs(row), 0);
                     if (!idx.data(eMyMoney::Model::IdRole).toString().isEmpty() && isJournalModel(idx)) {
                         if (idx.data(eMyMoney::Model::TransactionPostDateRole).toDate() < startDate) {
                             startDate = idx.data(eMyMoney::Model::TransactionPostDateRole).toDate();
@@ -186,7 +192,7 @@ public:
             // take care of
             for (int row = parameter.firstRow; (row >= parameter.startRow) && (row <= parameter.lastRow); ++row) {
                 // check if we have the balance for this account
-                idx = q->index(qAbs(row), 0);
+                idx = sourceModel->index(qAbs(row), 0);
                 if (!(isJournalModel(idx) || isSchedulesJournalModel(idx))) {
                     continue;
                 }
@@ -207,7 +213,7 @@ public:
                 } else {
                     balances[accountId] += (shares * showValuesInverted);
                 }
-                q->setData(idx, QVariant::fromValue(balances[accountId]), eMyMoney::Model::JournalBalanceRole);
+                sourceModel->setData(idx, QVariant::fromValue(balances[accountId]), eMyMoney::Model::JournalBalanceRole);
             }
         }
     }
@@ -279,14 +285,15 @@ public:
             }
 
             // in case the source model is not sorting, we
-            // can assume that the item is visible. Once it
+            // can assume that the last item is visible. Once it
             // is sorted, it is early enough to perform the
             // other checks for reconciliation entries.
             // Not suppressing this this on an unsorted model
-            // may cause a hug performance penalty (looks like
+            // may cause a huge performance penalty (looks like
             // the application hung up in certain scenarios)
             if (!sourceModel->inSorting()) {
-                return true;
+                const auto filterMode = idx.data(eMyMoney::Model::ReconciliationFilterHintRole).value<eMyMoney::Model::ReconciliationFilterHint>();
+                return (filterMode == eMyMoney::Model::DontFilterLast) || (filterMode == eMyMoney::Model::DontFilter);
             }
 
             // in case we get here recursively, we simply assume
@@ -343,6 +350,7 @@ SpecialLedgerItemFilter::SpecialLedgerItemFilter(QObject* parent)
         // sort afresh in case some rows need to be resorted
         // doSort() inherits a call to invalidateFilter().
         doSort();
+        Q_EMIT sortFinished();
     });
 
     connect(MyMoneyFile::instance()->journalModel(), &JournalModel::balanceChanged, this, [&](const QString& accountId) {
@@ -496,6 +504,13 @@ bool SpecialLedgerItemFilter::filterAcceptsRow(int source_row, const QModelIndex
         }
         break;
 
+    case eMyMoney::Model::JournalEntryRole:
+        if (d->hideReconciledTransactions
+            && idx.data(eMyMoney::Model::SplitReconcileFlagRole).value<eMyMoney::Split::State>() >= eMyMoney::Split::State::Reconciled) {
+            return false;
+        }
+        break;
+
     default:
         break;
     }
