@@ -605,8 +605,7 @@ QMap<QDate, MyMoneyMoney> MyMoneyAccount::reconciliationHistory()
     Q_D(MyMoneyAccount);
 
     // check if the internal history member is already loaded
-    if (d->m_reconciliationHistory.count() == 0
-            && !value("reconciliationHistory").isEmpty()) {
+    if (d->m_reconciliationHistory.isEmpty() && !value("reconciliationHistory").isEmpty()) {
         const QStringList entries = value("reconciliationHistory").split(';');
         for (const auto& entry : qAsConst(entries)) {
             const auto parts = entry.split(':');
@@ -670,6 +669,19 @@ bool MyMoneyAccount::hasOnlineMapping() const
     return !d->m_onlineBankingSettings.value(QLatin1String("provider")).isEmpty();
 }
 
+QString MyMoneyAccount::stdAccName(eMyMoney::Account::Type type)
+{
+    static const QHash<eMyMoney::Account::Type, eMyMoney::Account::Standard> stdAccTypes{
+        {eMyMoney::Account::Type::Liability, eMyMoney::Account::Standard::Liability},
+        {eMyMoney::Account::Type::Asset, eMyMoney::Account::Standard::Asset},
+        {eMyMoney::Account::Type::Expense, eMyMoney::Account::Standard::Expense},
+        {eMyMoney::Account::Type::Income, eMyMoney::Account::Standard::Income},
+        {eMyMoney::Account::Type::Equity, eMyMoney::Account::Standard::Equity},
+    };
+    // make sure to operate only on accountGroups
+    return stdAccName(stdAccTypes.value(accountGroup(type)));
+}
+
 QString MyMoneyAccount::stdAccName(eMyMoney::Account::Standard stdAccID)
 {
     static const QHash<eMyMoney::Account::Standard, QString> stdAccNames {
