@@ -40,6 +40,13 @@ enum class PayeeCreation;
 namespace Icons {
 enum class Icon;
 }
+
+namespace eMyMoney {
+namespace Invest {
+enum class PriceMode;
+}
+}
+
 template <class T> class payeeIdentifierTyped;
 
 /**
@@ -596,6 +603,17 @@ public:
      */
     eMyMoney::Account::PayeeCreation payeeCreation() const;
 
+    /**
+     * set the pricing mode for this account used for investments
+     */
+    void setPriceMode(eMyMoney::Invest::PriceMode priceMode);
+
+    /**
+     * return the pricing mode for this account with
+     * eMyMoney::Invest::PriceMode::Price as default
+     */
+    eMyMoney::Invest::PriceMode priceMode() const;
+
     /**
      * This method returns a name that has a brokerage suffix of
      * the current name. It only works on investment accounts and
@@ -664,6 +682,7 @@ public:
     void setBudgetAccountType(eMyMoney::Account::Type type);
 
     static QString stdAccName(eMyMoney::Account::Standard stdAccID);
+    static QString stdAccName(eMyMoney::Account::Type type);
     static QString accountSeparator();
 
     static MyMoneyMoney balanceFactor(eMyMoney::Account::Type accountType);
@@ -691,11 +710,11 @@ inline MyMoneyAccount & MyMoneyAccount::operator=(MyMoneyAccount other) // krazy
 }
 
 /**
- * Make it possible to hold @ref MyMoneyAccount objects,
- * @ref accountTypeE and @ref amountTypeE inside @ref QVariant objects.
+ * Make it possible to hold objects inside @ref QVariant objects.
  */
 Q_DECLARE_METATYPE(MyMoneyAccount)
 Q_DECLARE_METATYPE(eMyMoney::Account::Type)
 Q_DECLARE_METATYPE(eMyMoney::Account::PayeeCreation)
+Q_DECLARE_METATYPE(eMyMoney::Account::Standard)
 
 #endif
