@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2004-2006 Ace Jones <acejones@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2005-2018 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2005-2025 Thomas Baumgart <tbaumgart@kde.org>
     SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,6 +21,9 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
+#include "mymoneyobject.h"
+#include "mymoneyobject_p.h"
+
 namespace eMyMoney {
 namespace Statement {
 enum class Element {
@@ -67,6 +70,8 @@ enum class Attribute {
     Category,
     SmallestFraction,
     Tags,
+    Price,
+    Fees,
 };
 qHashSeedType qHash(const Attribute key, qHashSeedType seed)
 {
@@ -153,11 +158,73 @@ QString getAttrName(const Statement::Attribute attr)
         {Statement::Attribute::Category,             QStringLiteral("version")},
         {Statement::Attribute::SmallestFraction,     QStringLiteral("smallestFraction")},
         {Statement::Attribute::Tags,                 QStringLiteral("tags")},
+        {Statement::Attribute::Fees,                 QStringLiteral("fees")},
+        {Statement::Attribute::Price,                 QStringLiteral("price")},
         // clang-format on
     };
     return attrNames[attr];
 }
 
+class MyMoneyStatementPrivate : public MyMoneyObjectPrivate
+{
+public:
+    MyMoneyStatementPrivate() = default;
+
+    MyMoneyStatementPrivate(const MyMoneyStatementPrivate& r)
+        : MyMoneyObjectPrivate(r)
+    {
+        *this = r;
+    }
+
+    MyMoneyStatementPrivate& operator=(const MyMoneyStatementPrivate& r)
+    {
+        MyMoneyObjectPrivate::operator=(r);
+        return *this;
+    }
+
+    void collectReferencedObjects() override
+    {
+        m_referencedObjects.clear();
+    }
+
+    int m_transactionCount{0};
+    int m_transactionsAdded{0};
+    int m_transactionsMatched{0};
+    int m_transactionDuplicates{0};
+    int m_payeesCreated{0};
+};
+
+MyMoneyStatement::MyMoneyStatement()
+    : MyMoneyObject(*new MyMoneyStatementPrivate)
+{
+}
+
+MyMoneyStatement::MyMoneyStatement(const MyMoneyStatement& other)
+    : MyMoneyObject(*new MyMoneyStatementPrivate(*other.d_func()))
+{
+    m_strAccountName = other.m_strAccountName;
+    m_strAccountNumber = other.m_strAccountNumber;
+    m_strBankCode = other.m_strBankCode;
+    m_accountId = other.m_accountId;
+
+    m_strCurrency = other.m_strCurrency;
+    m_dateBegin = other.m_dateBegin;
+    m_dateEnd = other.m_dateEnd;
+    m_closingBalance = other.m_closingBalance;
+    m_eType = other.m_eType;
+
+    m_listTransactions = other.m_listTransactions;
+    m_listPrices = other.m_listPrices;
+    m_listSecurities = other.m_listSecurities;
+
+    m_skipCategoryMatching = other.m_skipCategoryMatching;
+}
+
+MyMoneyStatement::MyMoneyStatement(const QString& id, const MyMoneyStatement& other)
+    : MyMoneyObject(*new MyMoneyStatementPrivate(*other.d_func()), id)
+{
+}
+
 void MyMoneyStatement::write(QDomElement& _root, QDomDocument* _doc) const
 {
     QDomElement e = _doc->createElement(getElName(Statement::Element::Statement));
@@ -192,6 +259,8 @@ void MyMoneyStatement::write(QDomElement& _root, QDomDocument* _doc) const
 
         if (m_eType == eMyMoney::Statement::Type::Investment) {
             p.setAttribute(getAttrName(Statement::Attribute::Shares), transaction.m_shares.toString());
+            p.setAttribute(getAttrName(Statement::Attribute::Price), transaction.m_price.toString());
+            p.setAttribute(getAttrName(Statement::Attribute::Fees), transaction.m_fees.toString());
             p.setAttribute(getAttrName(Statement::Attribute::Security), transaction.m_strSecurity);
             p.setAttribute(getAttrName(Statement::Attribute::SecurityId), transaction.m_strSecurityId);
             p.setAttribute(getAttrName(Statement::Attribute::BrokerageAccount), transaction.m_strBrokerageAccount);
@@ -276,6 +345,8 @@ bool MyMoneyStatement::read(const QDomElement& _e)
 
                 if (m_eType == eMyMoney::Statement::Type::Investment) {
                     t.m_shares = MyMoneyMoney(c.attribute(getAttrName(Statement::Attribute::Shares)));
+                    t.m_fees = MyMoneyMoney(c.attribute(getAttrName(Statement::Attribute::Fees)));
+                    t.m_price = MyMoneyMoney(c.attribute(getAttrName(Statement::Attribute::Price)));
                     t.m_strSecurity = c.attribute(getAttrName(Statement::Attribute::Security));
                     t.m_strSecurityId = c.attribute(getAttrName(Statement::Attribute::SecurityId));
                     t.m_strBrokerageAccount = c.attribute(getAttrName(Statement::Attribute::BrokerageAccount));
@@ -381,7 +452,8 @@ bool MyMoneyStatement::readXMLFile(MyMoneyStatement& _s, const QString& _filenam
 {
     bool result = false;
     QFile f(_filename);
-    f.open(QIODevice::ReadOnly);
+    if (!f.open(QIODevice::ReadOnly))
+        return result;
     QDomDocument* doc = new QDomDocument;
     if (doc->setContent(&f, false)) {
         QDomElement rootElement = doc->documentElement();
