@@ -165,7 +165,7 @@ struct AccountsModel::Private
                 continue;
             // parent does not exist?
             if (!_list.contains((*ita).parentAccountId())) {
-                const auto newParentid = MyMoneyAccount::stdAccName(static_cast<eMyMoney::Account::Standard>((*ita).accountGroup()));
+                const auto newParentid = MyMoneyAccount::stdAccName((*ita).accountType());
                 (*ita).setParentAccountId(newParentid);
                 qDebug() << "check account hierarchy:" << "reparented" << (*ita).id() << "to" << newParentid;
             }
@@ -572,7 +572,6 @@ QVariant AccountsModel::data(const QModelIndex& idx, int role) const
         return data(subIdx, role);
     }
 
-    MyMoneyAccount tradingCurrency;
     const auto isInvestmentAccount = account.accountType() == eMyMoney::Account::Type::Investment;
 
     switch(role) {
@@ -800,7 +799,7 @@ QVariant AccountsModel::data(const QModelIndex& idx, int role) const
     case eMyMoney::Model::AccountOnlineBalanceValueRole:
         if (d->hasOnlineBalance(account)) {
             auto balance = MyMoneyMoney(account.value("lastStatementBalance"));
-            // revert the sign for liability accouts
+            // revert the sign for liability accounts
             if (account.accountGroup() == eMyMoney::Account::Type::Liability) {
                 balance = -balance;
             }
@@ -1001,6 +1000,21 @@ QModelIndexList AccountsModel::indexListByName(const QString& name, const QModel
     return match(assetIndex(), Qt::DisplayRole, name, 1, Qt::MatchFixedString | Qt::MatchCaseSensitive | Qt::MatchRecursive);
 }
 
+MyMoneyAccount AccountsModel::itemByName(const QString& name, const QModelIndex& start) const
+{
+    if (start.isValid()) {
+        return d->itemByName(name, start);
+    }
+    const auto topLevelIndexes = match(assetIndex(), eMyMoney::Model::IdRole, QLatin1String("*"), -1, Qt::MatchWildcard);
+    for (const auto& topLevelIndex : topLevelIndexes) {
+        const auto item = itemByName(name, topLevelIndex);
+        if (!item.id().isEmpty()) {
+            return item;
+        }
+    }
+    return {};
+}
+
 void AccountsModel::addFavorite(const QString& id)
 {
     // no need to do anything if it is already listed
@@ -1132,13 +1146,17 @@ void AccountsModel::updateAccountBalances(const QHash<QString, AccountBalances>&
     d->updateOnBalanceChange = false;
     bool approximate = false;
     for (auto it = balances.cbegin(); it != balances.cend(); ++it) {
-        MyMoneyAccount& account = static_cast<TreeItem<MyMoneyAccount>*>(indexById(it.key()).internalPointer())->dataRef();
-        account.setBalance(it.value().m_totalBalance);
+        const auto index = indexById(it.key());
+        if (index.isValid()) {
+            MyMoneyAccount& account = static_cast<TreeItem<MyMoneyAccount>*>(index.internalPointer())->dataRef();
+            account.setBalance(it.value().m_totalBalance);
+            const auto result = d->balanceToValue(account, it.value().m_totalBalance);
 
-        const auto result = d->balanceToValue(account, it.value().m_totalBalance);
-
-        account.setPostedValue(result.first);
-        approximate |= result.second;
+            account.setPostedValue(result.first);
+            approximate |= result.second;
+        } else {
+            qDebug() << "AccountsModel::updateAccountBalances" << it.key() << "not found in model.";
+        }
     }
 
     // now that we have all values, we can calculate the total values in the parent accounts
