@@ -322,8 +322,8 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, MyMoneyFile* file)
             s << "  Enddate   = " << (*it_s).endDate().toString(Qt::ISODate) << "\n";
         else
             s << "  Enddate   = not specified\n";
-        s << "  Occurence = " << (*it_s).occurrenceToString() << "\n"; // krazy:exclude=spelling
-        s << "  OccurenceMultiplier = " << (*it_s).occurrenceMultiplier() << "\n"; // krazy:exclude=spelling
+        s << "  Occurrence = " << (*it_s).occurrenceToString() << "\n"; // krazy:exclude=spelling
+        s << "  OccurrenceMultiplier = " << (*it_s).occurrenceMultiplier() << "\n"; // krazy:exclude=spelling
         s << "  Type = " << MyMoneySchedule::scheduleTypeToString((*it_s).type()) << "\n";
         s << "  Paymenttype = " << MyMoneySchedule::paymentMethodToString((*it_s).paymentType()) << "\n";
         s << "  Fixed = " << (*it_s).isFixed() << "\n";
