@@ -3,7 +3,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "mymoneyutils.h"
+#include "mymoneytestutils.h"
 
 #include "mymoneyexception.h"
 
@@ -12,3 +12,4 @@ QString unexpectedExceptionString(const MyMoneyException &e)
     return QString("Unexpected exception: %1").arg(e.what());
 }
 
+QtMessageHandler MyMoneyHideDebugTestBase::oldHandler = nullptr;
