@@ -13,10 +13,15 @@
 #include <QLabel>
 #include <QRegularExpression>
 #include <QTemporaryFile>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QUuid>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QTextCodec>
+#else
+#include <QStringDecoder>
+#endif
+
 // ----------------------------------------------------------------------------
 // KDE Includes
 
@@ -81,7 +86,9 @@ bool KOfxDirectConnectDlg::init()
     if (KMyMoneySettings::logOfxTransactions()) {
         QString logPath = KMyMoneySettings::logPath();
         d->m_fpTrace.setFileName(QString("%1/ofxlog.txt").arg(logPath));
-        d->m_fpTrace.open(QIODevice::WriteOnly | QIODevice::Append);
+        if (d->m_fpTrace.open(QIODevice::WriteOnly | QIODevice::Append)) {
+            ; // nothing here, just making the compiler happy
+        }
     }
 
     // Check if we need to tweak the request for specific institutions
@@ -100,9 +107,15 @@ bool KOfxDirectConnectDlg::init()
         d->m_fpTrace.write("response:\n", 10);
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto codec = QTextCodec::codecForName("Windows-1251");
-    qDebug() << "creating job"; // << codec->fromUnicode(request);
-    m_job = KIO::http_post(QUrl(m_connector.url()), codec->fromUnicode(request), KIO::HideProgressInfo);
+    const auto encodedRequest = codec->fromUnicode(request);
+#else
+    auto fromUtf16 = QStringEncoder("Windows-1251");
+    const auto encodedRequest = fromUtf16(request);
+#endif
+    qDebug() << "creating job"; // << encodedRequest;
+    m_job = KIO::http_post(QUrl(m_connector.url()), encodedRequest, KIO::HideProgressInfo);
 
     // open the temp file. We come around here twice if init() is called twice
     if (m_tmpfile) {
