@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2014 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -32,7 +33,7 @@ class onlineJobPluginMockup : public KMyMoneyPlugin::OnlinePluginExtended
                  KMyMoneyPlugin::OnlinePlugin)
 
 public:
-    explicit onlineJobPluginMockup(QObject *parent, const QVariantList &args);
+    explicit onlineJobPluginMockup(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~onlineJobPluginMockup() override;
 
     void protocols(QStringList& protocolList) const override;
@@ -43,7 +44,7 @@ public:
 
     bool updateAccount(const MyMoneyAccount& acc, bool moreAccounts = false) override;
 
-    QStringList availableJobs(QString accountId) override;
+    QStringList availableJobs(QString accountId) const override;
     IonlineTaskSettings::ptr settings(QString accountId, QString taskName) override;
     void sendOnlineJob(QList< onlineJob >& jobs) override;
     void plug() override {}
