@@ -1,29 +1,24 @@
 /*
- * This file is part of KMyMoney, A Personal Finance Manager by KDE
- * Copyright (C) 2013 Christian Dávid <christian-david@web.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+
+    SPDX-FileCopyrightText: 2013 Christian Dávid <christian-david@web.de>
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef ONLINETASK_H
 #define ONLINETASK_H
 
+#include "onlinetask_interfaces_export.h"
+
 #include <QString>
 
 #include <qobject.h>
 
+#include <kmmset.h>
+
 class onlineJob;
+class QXmlStreamReader;
+class QXmlStreamWriter;
 
 /**
  * @brief Enables onlineTask meta system
@@ -106,64 +101,77 @@ class onlineJob;
  */
 class QDomDocument;
 class QDomElement;
-class onlineTask
+class ONLINETASK_INTERFACES_EXPORT onlineTask
 {
 public:
-  ONLINETASK_META_BASE(onlineTask, "org.kmymoney.onlineTask", /* no attribute here */);
-  onlineTask();
-  virtual ~onlineTask() {}
+    ONLINETASK_META_BASE(onlineTask, "org.kmymoney.onlineTask", /* no attribute here */);
+    onlineTask();
+    virtual ~onlineTask() {}
 
-  /**
-   * @brief Checks if the task is ready for sending
-   */
-  virtual bool isValid() const = 0;
+    /**
+     * @brief Checks if the task is ready for sending
+     */
+    virtual bool isValid() const = 0;
 
-  /**
-   * @brief Human readable type-name
-   */
-  virtual QString jobTypeName() const = 0;
+    /**
+     * @brief Human readable type-name
+     */
+    virtual QString jobTypeName() const = 0;
 
-  /** @see MyMoneyObject::writeXML() */
-  virtual void writeXML(QDomDocument &document, QDomElement &parent) const = 0;
+    /** @see MyMoneyObject::writeXML() */
+    virtual void writeXML(QXmlStreamWriter* writer) const = 0;
 
 protected:
-  onlineTask(const onlineTask& other);
+    onlineTask(const onlineTask& other);
 
-  /**
-   * @brief Copy this instance including inherited information
-   *
-   * This method copies an onlineJob including all information which are stored in inherited classes
-   * even if you do not know the final type of an reference or pointer.
-   */
-  virtual onlineTask* clone() const = 0;
+    /**
+     * @brief Copy this instance including inherited information
+     *
+     * This method copies an onlineJob including all information which are stored in inherited classes
+     * even if you do not know the final type of an reference or pointer.
+     */
+    virtual onlineTask* clone() const = 0;
 
-  /** @see MyMoneyObject::hasReferenceTo() */
-  virtual bool hasReferenceTo(const QString &id) const = 0;
+    /** @see MyMoneyObject::hasReferenceTo() */
+    virtual bool hasReferenceTo(const QString &id) const = 0;
 
-  /**
-   * @brief Create a new instance of this task based on xml data
-   *
-   * This method is used to load an onlineTask from a xml file.
-   *
-   * This method is created const as it should create a @emph new onlineTask.
-   * @return A pointer to a new instance, caller takes ownership
-   */
-  virtual onlineTask* createFromXml(const QDomElement &element) const = 0;
+    /**
+     * @copydoc MyMoneyObject::referencedObjects
+     */
+    virtual KMMStringSet referencedObjects() const = 0;
 
-  /**
-   * @brief Account this job is related to
-   *
-   * Each task must have an account on which it operates. This is used to determine
-   * the correct onlinePlugin which can execute this job. If the job is related to more
-   * than one account (e.g. a password change) select a random one.
-   *
-   * You can make this method public if it is useful for you.
-   *
-   * @return accountId
-   */
-  virtual QString responsibleAccount() const = 0;
+    /**
+     * @brief Create a new instance of this task based on xml data
+     *
+     * This method is used to load an onlineTask from a xml file.
+     *
+     * This method is created const as it should create a @emph new onlineTask.
+     * @return A pointer to a new instance, caller takes ownership
+     */
+    virtual onlineTask* createFromXml(QXmlStreamReader* reader) const = 0;
 
-  friend class onlineJob;
+    /**
+     * @brief Account this job is related to
+     *
+     * Each task must have an account on which it operates. This is used to determine
+     * the correct onlinePlugin which can execute this job. If the job is related to more
+     * than one account (e.g. a password change) select a random one.
+     *
+     * You can make this method public if it is useful for you.
+     *
+     * @return accountId
+     */
+    virtual QString responsibleAccount() const = 0;
+
+    /**
+     * @brief Purpose of the job
+     *
+     * Each job may contain a description what it is used for.
+     */
+    virtual QString purpose() const = 0;
+
+    friend class onlineJob;
+    friend class onlineJobPrivate;
 };
 
 Q_DECLARE_INTERFACE(onlineTask, "org.kmymoney.onlinetask");
