@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
     SPDX-FileCopyrightText: 2019 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -9,8 +10,6 @@
 
 // ----------------------------------------------------------------------------
 // QT Includes
-#include <QCoreApplication>
-#include <QStandardPaths>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -23,28 +22,17 @@
 // Project Includes
 
 #include "kexportdlg.h"
+
 #include "mymoneyqifwriter.h"
-#include "mymoneyutils.h"
 #include "viewinterface.h"
 
-QIFExporter::QIFExporter(QObject *parent, const QVariantList &args) :
-    KMyMoneyPlugin::Plugin(parent, "qifexporter"/*must be the same as X-KDE-PluginInfo-Name*/)
+QIFExporter::QIFExporter(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args) :
+    KMyMoneyPlugin::Plugin(parent, metaData, args)
 {
-    Q_UNUSED(args);
-    const auto componentName = QLatin1String("qifexporter");
+    Q_INIT_RESOURCE(qifexporter);
+
     const auto rcFileName = QLatin1String("qifexporter.rc");
-    setComponentName(componentName, i18n("QIF exporter"));
-
-    if (MyMoneyUtils::isRunningAsAppImage()) {
-        const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
-        setXMLFile(rcFilePath);
-
-        const QString localRcFilePath =
-            QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
-        setLocalXMLFile(localRcFilePath);
-    } else {
-        setXMLFile(rcFileName);
-    }
+    setXMLFile(rcFileName);
 
     createActions();
     // For information, announce that we have been loaded.
@@ -74,7 +62,6 @@ void QIFExporter::slotQifExport()
     if (dlg->exec() == QDialog::Accepted && dlg != nullptr) {
 //    if (okToWriteFile(QUrl::fromLocalFile(dlg->filename()))) {
         MyMoneyQifWriter writer;
-        connect(&writer, SIGNAL(signalProgress(int,int)), this, SLOT(slotStatusProgressBar(int,int)));
 
         writer.write(dlg->filename(), dlg->profile(), dlg->accountId(),
                      dlg->accountSelected(), dlg->categorySelected(),
@@ -85,6 +72,6 @@ void QIFExporter::slotQifExport()
     m_action->setEnabled(true);
 }
 
-K_PLUGIN_FACTORY_WITH_JSON(QIFExporterFactory, "qifexporter.json", registerPlugin<QIFExporter>();)
+K_PLUGIN_CLASS_WITH_JSON(QIFExporter, "qifexporter.json")
 
 #include "qifexporter.moc"
