@@ -232,8 +232,7 @@ bool KReportsView::eventFilter(QObject* watched, QEvent* event)
         for (const auto& button : qAsConst(buttons)) {
             const auto action = button->defaultAction();
             if (action) {
-                const auto actionSeq = action->shortcut();
-                if (keySeq == actionSeq) {
+                if (action->shortcuts().contains(keySeq)) {
                     action->trigger();
                     event->accept();
                     return true;
@@ -321,7 +320,7 @@ void KReportsView::slotOpenUrl(const QUrl &url)
         selection.setSelection(SelectedObjects::JournalEntry, tid);
         Q_EMIT requestSelectionChange(selection);
 
-        gotoAccount->trigger();
+        MyMoneyUtils::triggerAction(gotoAccount);
     } else {
         qWarning() << i18n("Unknown view '%1' in KReportsView::slotOpenUrl()", qPrintable(view));
     }
