@@ -24,6 +24,7 @@
 #include "mymoneyaccount.h"
 #include "mymoneybudget.h"
 #include "mymoneycostcenter.h"
+#include "mymoneyexception.h"
 #include "mymoneyfile.h"
 #include "mymoneyinstitution.h"
 #include "mymoneykeyvaluecontainer.h"
@@ -187,6 +188,7 @@ public:
     MyMoneySecurity m_security;
     MyMoneyPrice m_price;
     onlineJob m_onlineJob;
+    QSet<QString> m_validAccountIds;
 
     uint m_fileVersionRead;
 
@@ -253,7 +255,7 @@ public:
 
         // there are multiple identifiers used for the state in different
         // locations of the KMM file. We try to read all until we find an
-        // entry to maintain backward compatability
+        // entry to maintain backward compatibility
         rc.state = readStringAttribute(attributeName(Attribute::General::State));
         if (rc.state.isEmpty()) {
             rc.state = readStringAttribute(attributeName(Attribute::General::Country));
@@ -264,7 +266,7 @@ public:
 
         // there are multiple identifiers used for the zipcode in different
         // locations of the KMM file. We try to read all until we find an
-        // entry to maintain backward compatability
+        // entry to maintain backward compatibility
         rc.zipcode = readStringAttribute(attributeName(Attribute::General::ZipCode));
         if (rc.zipcode.isEmpty()) {
             rc.zipcode = readStringAttribute(attributeName(Attribute::General::AltZipCode));
@@ -442,7 +444,7 @@ public:
         } else if (identifierType == payeeIdentifiers::nationalAccount::staticPayeeIdentifierIid()) {
             identData = readNationalAccount();
         } else {
-            m_reader->raiseError(i18nc("Error message when reading XML file", "Unknown payee identifier type %1").arg(identifierType));
+            m_reader->raiseError(i18nc("Error message when reading XML file", "Unknown payee identifier type %1", identifierType));
         }
 
         return identData;
@@ -652,6 +654,9 @@ public:
         Q_ASSERT(m_reader->isStartElement() && (m_reader->name() == nodeName(Node::Account)));
 
         m_account = MyMoneyAccount(readId());
+        if (!MyMoneyFile::instance()->isStandardAccount(m_account.id())) {
+            m_validAccountIds.insert(m_account.id());
+        }
         m_account.setName(readStringAttribute(attributeName(Attribute::Account::Name)));
         m_account.setDescription(readStringAttribute(attributeName(Attribute::Account::Description)));
         m_account.setParentAccountId(readStringAttribute(attributeName(Attribute::Account::ParentAccount)));
@@ -762,6 +767,13 @@ public:
         m_split.setNumber(readStringAttribute(attributeName(Attribute::Split::Number)));
         m_split.setBankID(readStringAttribute(attributeName(Attribute::Split::BankID)));
 
+        if (!m_validAccountIds.contains(m_split.accountId())) {
+            throw MYMONEYEXCEPTION(i18nc("@info XML reader",
+                                         "Corrupted data: transaction '%1', split '%2' references unknown account id '%3'",
+                                         m_transaction.id(),
+                                         readId(),
+                                         m_split.accountId()));
+        }
         QList<QString> tagList;
         while (m_reader->readNextStartElement()) {
             const auto tag = m_reader->name();
