@@ -39,10 +39,12 @@
 #include "mymoneyutils.h"
 #include "newtransactioneditor.h"
 #include "schedulesjournalmodel.h"
+#include "tagsmodel.h"
 
 struct displayProperties {
     int italicStartLine;
     QStringList lines;
+    QStringList tagIds;
 };
 
 class JournalDelegate::Private
@@ -97,12 +99,27 @@ public:
         displayProperties rc;
         rc.italicStartLine = -1;
 
-        const auto showAllSplits = LedgerViewSettings::instance()->showAllSplits();
+        auto addTags = [&]() -> void {
+            if (index.data(eMyMoney::Model::TransactionSplitCountRole).toInt() == 2) {
+                const auto rowIndeces =
+                    MyMoneyFile::instance()->journalModel()->indexesByTransactionId(index.data(eMyMoney::Model::JournalTransactionIdRole).toString());
+                const auto rowCount = rowIndeces.count();
+                const auto splitId = index.data(eMyMoney::Model::IdRole).toString();
+                for (int row = 0; row < rowCount; ++row) {
+                    const auto rowIndex = rowIndeces[row];
+                    if (rowIndex.data(eMyMoney::Model::IdRole) != splitId) {
+                        rc.tagIds = rowIndex.data(eMyMoney::Model::SplitTagIdRole).toStringList();
+                        break;
+                    }
+                }
+            }
+        };
+        const auto showLedgerLens = LedgerViewSettings::instance()->showLedgerLens();
+        const auto showAllSplits = LedgerViewSettings::instance()->showAllSplits() & showLedgerLens;
+        const auto havePayeeColumn = !m_view->isColumnHidden(JournalModel::Payee);
 
         if(index.column() == JournalModel::Column::Detail) {
             const auto showDetails = LedgerViewSettings::instance()->showTransactionDetails();
-            const auto showLedgerLens = LedgerViewSettings::instance()->showLedgerLens();
-            const auto havePayeeColumn = !m_view->isColumnHidden(JournalModel::Payee);
 
             if (index.data(eMyMoney::Model::TransactionIsInvestmentRole).toBool() && isInvestmentView()) {
                 if (((opt.state & QStyle::State_Selected) && (showLedgerLens)) || showDetails || showAllSplits) {
@@ -176,6 +193,7 @@ public:
                     }
                     rc.lines << index.data(eMyMoney::Model::Roles::TransactionCounterAccountRole).toString();
                     rc.lines << index.data(eMyMoney::Model::Roles::SplitStyledSingleLineMemoRole).toString();
+                    addTags();
 
                 } else {
                     if (rc.lines.at(0).isEmpty()) {
@@ -183,6 +201,7 @@ public:
                         rc.lines << index.data(eMyMoney::Model::Roles::SplitStyledSingleLineMemoRole).toString();
                     }
                     if (rc.lines.at(0).isEmpty()) {
+                        rc.lines.clear();
                         rc.lines << index.data(eMyMoney::Model::Roles::TransactionCounterAccountRole).toString();
                     }
                 }
@@ -192,7 +211,6 @@ public:
         } else if(index.column() == JournalModel::Column::Quantity) {
             if (index.data(eMyMoney::Model::TransactionIsInvestmentRole).toBool()) {
                 const auto showDetails = LedgerViewSettings::instance()->showTransactionDetails();
-                const auto showLedgerLens = LedgerViewSettings::instance()->showLedgerLens();
                 rc.lines << opt.text;
                 if (((opt.state & QStyle::State_Selected) && (showLedgerLens)) || showDetails) {
                     // we have to pay attention here as later on empty items will be removed
@@ -229,7 +247,6 @@ public:
             }
 
         } else if (index.column() == JournalModel::Column::Deposit) {
-            const auto havePayeeColumn = !m_view->isColumnHidden(JournalModel::Payee);
             rc.lines << opt.text;
             if (showAllSplits && isMultiSplitDisplay(index)) {
                 const auto payee = index.data(eMyMoney::Model::SplitPayeeRole).toString();
@@ -241,7 +258,6 @@ public:
             }
 
         } else if (index.column() == JournalModel::Column::Payment) {
-            const auto havePayeeColumn = !m_view->isColumnHidden(JournalModel::Payee);
             rc.lines << opt.text;
             if (showAllSplits && isMultiSplitDisplay(index)) {
                 const auto payee = index.data(eMyMoney::Model::SplitPayeeRole).toString();
@@ -518,8 +534,8 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
 
             opt.backgroundBrush = opt.palette.base();
             if (selected) {
-                // always use the normal palette since the background is also in normal
-                painter->setPen(opt.palette.color(QPalette::ColorGroup(QPalette::Normal), QPalette::HighlightedText));
+                opt.backgroundBrush = opt.palette.brush(cg, QPalette::Highlight);
+                painter->setPen(opt.palette.color(cg, QPalette::HighlightedText));
                 style->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter, opt.widget);
 
             } else if (erroneous) {
@@ -541,11 +557,6 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 style->drawPrimitive(QStyle::PE_PanelItemViewRow, &opt, painter, opt.widget);
             }
 
-            if (opt.state & QStyle::State_Editing) {
-                painter->setPen(opt.palette.color(cg, QPalette::Text));
-                painter->drawRect(textArea.adjusted(0, 0, -1, -1));
-            }
-
             painter->save();
             // collect data for the various columns
             for (int i = 0; i < lineCount; ++i) {
@@ -557,6 +568,21 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 }
                 painter->drawText(textArea.adjusted(0, lineHeight * i, 0, 0), opt.displayAlignment, displayProperties.lines[i]);
             }
+            // get original painter back
+            painter->restore();
+            painter->save();
+
+            if ((index.column() == JournalModel::Column::Detail) && !displayProperties.tagIds.isEmpty()) {
+                QString txt = i18ncp("Label for tags in ledger", "Tag: ", "Tags: ", displayProperties.tagIds.count());
+                QStringList tags;
+
+                for (const auto& tagId : displayProperties.tagIds) {
+                    const auto tag = MyMoneyFile::instance()->tagsModel()->itemById(tagId);
+                    tags << tag.name();
+                }
+                txt.append(tags.join(", "));
+                painter->drawText(textArea.adjusted(0, lineHeight * lineCount, 0, 0), opt.displayAlignment, txt);
+            }
             painter->restore();
 
             if (matchedLineCount > 0) {
@@ -571,20 +597,6 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
             }
         }
 
-        // draw the focus rect
-        if(opt.state & QStyle::State_HasFocus) {
-            QStyleOptionFocusRect o;
-            o.QStyleOption::operator=(opt);
-            o.rect = style->proxy()->subElementRect(QStyle::SE_ItemViewItemFocusRect, &opt, opt.widget);
-            o.state |= QStyle::State_KeyboardFocusChange;
-            o.state |= QStyle::State_Item;
-
-            cg = (opt.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
-            o.backgroundColor = opt.palette.color(cg, (opt.state & QStyle::State_Selected)
-                                                  ? QPalette::Highlight : QPalette::Window);
-            style->proxy()->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter, opt.widget);
-        }
-
         // take care of icons on the transaction
         if (index.column() == JournalModel::Column::Detail) {
             QRect iconArea = QRect(opt.rect.x() + margin, opt.rect.y(), opt.rect.width() - 2 * margin, opt.rect.height());
@@ -617,16 +629,19 @@ void JournalDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
                 }
             }
         }
-    } else {
-        // Skip painting the CE_FocusFrame on Windows and with AppImages
-        // because it seems to be the cause that the background of the
-        // editor is painted completely black.
-#ifndef Q_OS_WIN
-        if (!AlkEnvironment::isRunningAsAppImage()) {
-            // paint focus frame around edit widget
-            style->drawControl(QStyle::CE_FocusFrame, &opt, painter, editWidget);
-        }
-#endif
+    }
+
+    if (opt.state & QStyle::State_HasFocus) {
+        QStyleOptionFocusRect o;
+        o.QStyleOption::operator=(opt);
+        o.rect = style->proxy()->subElementRect(QStyle::SE_ItemViewItemFocusRect, &opt, opt.widget);
+        o.state |= QStyle::State_KeyboardFocusChange;
+        o.state |= QStyle::State_Item;
+
+        QPalette::ColorGroup cg;
+        cg = (opt.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
+        o.backgroundColor = opt.palette.color(cg, (opt.state & QStyle::State_Selected) ? QPalette::Highlight : QPalette::Window);
+        style->proxy()->drawPrimitive(QStyle::PE_FrameFocusRect, &o, painter, opt.widget);
     }
 
     painter->restore();
@@ -639,15 +654,18 @@ void JournalDelegate::resetLineHeight()
 
 QSize JournalDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
+    QStyleOptionViewItem opt = option;
+    initStyleOption(&opt, index);
+    QStyle* style = opt.widget ? opt.widget->style() : QApplication::style();
+
     // get parameters only once per update to speed things up
     if (d->m_lineHeight == -1) {
-        QStyleOptionViewItem opt = option;
-        initStyleOption(&opt, index);
-        QStyle *style = opt.widget ? opt.widget->style() : QApplication::style();
         d->m_margin = style->pixelMetric(QStyle::PM_FocusFrameHMargin);
         d->m_lineHeight = opt.fontMetrics.lineSpacing();
     }
 
+    bool resizeSection(false);
+
     if(index.isValid()) {
         // check if we are showing the edit widget
         // const QAbstractItemView *view = qobject_cast<const QAbstractItemView *>(opt.widget);
@@ -659,11 +677,20 @@ QSize JournalDelegate::sizeHint(const QStyleOptionViewItem& option, const QModel
                     return editor->minimumSizeHint();
                 }
             }
+            resizeSection = d->m_view->isResizingSectionToContents();
         }
     }
 
     QSize size(10, d->m_lineHeight + 2 * d->m_margin);
 
+    // only when we are requested by the user to resize the
+    // column to the content (user double clicked on section
+    // header) we do this more expensive operation
+    if (resizeSection) {
+        size = style->sizeFromContents(QStyle::CT_ItemViewItem, &opt, QSize(), opt.widget);
+        size.setHeight(d->m_lineHeight + 2 * d->m_margin);
+    }
+
     const auto settings = LedgerViewSettings::instance();
     if (((option.state & QStyle::State_Selected) && (settings->showLedgerLens())) || settings->showTransactionDetails()) {
         auto rows = index.data(eMyMoney::Model::JournalSplitMaxLinesCountRole).toInt();
@@ -672,7 +699,9 @@ QSize JournalDelegate::sizeHint(const QStyleOptionViewItem& option, const QModel
             const QList<int> columns = {JournalModel::Column::Detail, JournalModel::Column::Deposit, JournalModel::Column::Payment};
             for (const auto& column : qAsConst(columns)) {
                 const auto idx = index.model()->index(index.row(), column);
-                const auto rowCount = d->displayString(idx, option).lines.count() + d->displayMatchedString(idx, option).lines.count();
+                const auto displayString = d->displayString(idx, option);
+                const auto displayMatchedString = d->displayMatchedString(idx, option);
+                const auto rowCount = displayString.lines.count() + (displayString.tagIds.isEmpty() ? 0 : 1) + displayMatchedString.lines.count();
                 if (rowCount > rows) {
                     rows = rowCount;
                 }
