@@ -92,9 +92,11 @@ QString QPixmapToDataUri(const QPixmap& pixmap)
     QImage image(pixmap.toImage());
     QByteArray byteArray;
     QBuffer buffer(&byteArray);
-    buffer.open(QIODevice::WriteOnly);
-    image.save(&buffer, "PNG"); // writes the image in PNG format inside the buffer
-    return QLatin1String("data:image/png;base64,") + QString(byteArray.toBase64());
+    if (buffer.open(QIODevice::WriteOnly)) {
+        image.save(&buffer, "PNG"); // writes the image in PNG format inside the buffer
+        return QLatin1String("data:image/png;base64,") + QString(byteArray.toBase64());
+    }
+    return {};
 }
 
 bool accountNameLess(const MyMoneyAccount &acc1, const MyMoneyAccount &acc2)
@@ -162,11 +164,14 @@ public:
 
         q->connect(m_view, &QTextBrowser::anchorClicked, q, &KHomeView::slotOpenUrl);
 
-        q->connect(MyMoneyFile::instance(), &MyMoneyFile::dataChanged, q, &KHomeView::refresh);
+        q->connect(MyMoneyFile::instance(), &MyMoneyFile::dataChanged, q, &KHomeView::delayedRefresh);
 
         m_resizeRefreshTimer.setSingleShot(true);
         q->connect(&m_resizeRefreshTimer, &QTimer::timeout, q, &KHomeView::refresh);
 
+        m_refreshDelayTimer.setSingleShot(true);
+        q->connect(&m_refreshDelayTimer, &QTimer::timeout, q, &KHomeView::refresh);
+
         m_needsRefresh = false;
     }
 
@@ -354,7 +359,7 @@ public:
 
     /**
      * Print text in the color set for negative numbers, if @p amount is negative
-     * abd @p isNegative is true
+     * and @p isNegative is true
      */
     QString showColoredAmount(const QString& amount, bool isNegative)
     {
@@ -497,13 +502,15 @@ public:
                         break;
 
                     case 3: // payment accounts
+                    {
+                        const auto sectionHeader = i18nc("@title Home page section", "Payment Accounts");
                         // Check if preferred accounts are shown separately
                         if (settings.contains("2")) {
-                            showAccounts(static_cast<paymentTypeE>(Payment | Preferred), i18n("Payment Accounts"));
+                            showAccounts(Payment, sectionHeader);
                         } else {
-                            showAccounts(Payment, i18nc("@title Home page section", "Payment Accounts"));
+                            showAccounts(static_cast<paymentTypeE>(Payment | Preferred), sectionHeader);
                         }
-                        break;
+                    } break;
                     case 4: // favorite reports
                         showFavoriteReports();
                         break;
@@ -826,13 +833,22 @@ public:
                 if (!sched.isFinished()) {
                     // walk over splits in two rounds: the first takes
                     // care of the main split and the second of all
-                    // others
+                    // others. For transfers, we only do one round, though.
                     bool processMainSplit(true);
+
+                    const auto splits = t.splits();
+                    QVector<MyMoneyAccount> accounts;
+                    for (const auto& sp : qAsConst(splits)) {
+                        accounts.append(file->account(sp.accountId()));
+                    }
+                    bool isTransfer =
+                        ((splits.count() == 2) && (accounts.count() == 2) && (accounts[0].isAssetLiability()) && (accounts[1].isAssetLiability()));
+
                     do {
-                        const auto splits = t.splits();
+                        int idx = 0;
                         for (const auto& sp : qAsConst(splits)) {
                             if (processMainSplit == (sp.accountId() == mainAccount.id())) {
-                                const auto account = file->account(sp.accountId());
+                                const auto& account = accounts.at(idx);
                                 if (account.isAssetLiability()) {
                                     QString tmp = QString("<tr class=\"row-%1\">").arg(index++ & 0x01 ? "even" : "odd");
 
@@ -863,35 +879,64 @@ public:
                                     tmp += "</td><td>";
                                     tmp += link(VIEW_LEDGER, QString("?id=%1").arg(account.id())) + account.name() + linkend();
 
+                                    if (isTransfer) {
+                                        const auto& counterAccount = accounts.at(idx ^ 1);
+                                        tmp += QLatin1String("<br>") + link(VIEW_LEDGER, QString("?id=%1").arg(counterAccount.id())) + counterAccount.name()
+                                            + linkend();
+                                    }
+
                                     // show amount of the schedule
                                     tmp += "</td><td class=\"right nowrap\">";
 
-                                    const MyMoneySecurity& currency = MyMoneyFile::instance()->currency(account.currencyId());
-                                    MyMoneyMoney payment = MyMoneyMoney(sp.value(t.commodity(), account.currencyId()) * cnt);
-                                    QString amount = MyMoneyUtils::formatMoney(payment, account, currency);
-                                    amount.replace(QChar(' '), "&nbsp;");
-                                    tmp += showColoredAmount(amount, payment.isNegative());
+                                    auto addAmount = [&](int i) -> QString {
+                                        MyMoneySecurity currency = MyMoneyFile::instance()->currency(accounts.at(i).currencyId());
+                                        MyMoneyMoney payment = MyMoneyMoney(splits.at(i).value(t.commodity(), currency.id()) * cnt);
+                                        QString amount = MyMoneyUtils::formatMoney(payment, accounts.at(i), currency);
+                                        amount.replace(QChar(' '), "&nbsp;");
+                                        return showColoredAmount(amount, payment.isNegative());
+                                    };
+
+                                    tmp += addAmount(idx);
+                                    if (isTransfer) {
+                                        tmp += QLatin1String("<br>") + addAmount(idx ^ 1);
+                                    }
                                     tmp += "</td>";
+
                                     // show balance after payments
                                     tmp += "<td class=\"right nowrap\">";
                                     QDate paymentDate = QDate(sched.adjustedNextDueDate());
-                                    MyMoneyMoney balanceAfter = forecastPaymentBalance(account, payment, paymentDate);
-                                    QString balance = MyMoneyUtils::formatMoney(balanceAfter, account, currency);
-                                    balance.replace(QChar(' '), "&nbsp;");
-                                    tmp += showColoredAmount(balance, balanceAfter.isNegative());
+
+                                    auto addBalance = [&](int i) -> QString {
+                                        MyMoneySecurity currency = MyMoneyFile::instance()->currency(accounts.at(i).currencyId());
+                                        MyMoneyMoney payment = MyMoneyMoney(splits.at(i).value(t.commodity(), currency.id()) * cnt);
+                                        MyMoneyMoney balanceAfter = forecastPaymentBalance(accounts.at(i), payment, paymentDate);
+                                        QString balance = MyMoneyUtils::formatMoney(balanceAfter, accounts.at(i), currency);
+                                        balance.replace(QChar(' '), "&nbsp;");
+                                        return showColoredAmount(balance, balanceAfter.isNegative());
+                                    };
+
+                                    tmp += addBalance(idx);
+                                    if (isTransfer) {
+                                        tmp += QLatin1String("<br>") + addBalance(idx ^ 1);
+                                    }
                                     tmp += "</td></tr>";
 
                                     // qDebug("paymentEntry = '%s'", tmp.toLatin1());
                                     m_html += tmp;
+
+                                    if (isTransfer) {
+                                        break;
+                                    }
                                 }
                             }
+                            ++idx;
                         }
                         if (processMainSplit) {
                             processMainSplit = false;
                             continue;
                         }
                         break;
-                    } while (true);
+                    } while (!isTransfer);
                 }
             }
         } catch (const MyMoneyException &e) {
@@ -907,6 +952,7 @@ public:
         QList<MyMoneyAccount> accounts;
 
         const auto showAllAccounts = KMyMoneySettings::showAllAccounts();
+        const bool hideZeroBalanceAccounts = KMyMoneySettings::hideZeroBalanceAccountsHome() && !showAllAccounts;
 
         // get list of all accounts
         file->accountList(accounts);
@@ -971,6 +1017,11 @@ public:
                 removeAccount = true;
             }
 
+            // don't show zero balance accounts if the option is active
+            if (MyMoneyFile::instance()->balance((*it).id()).isZero() && hideZeroBalanceAccounts) {
+                removeAccount = true;
+            }
+
             if (removeAccount)
                 it = accounts.erase(it);
             else
@@ -1011,7 +1062,8 @@ public:
             if (KMyMoneySettings::showDateOfLastReconciliation())
                 m_html += QString("<td>%1</td>").arg(i18n("Reconciled"));
 
-            m_html += "<td width=\"10%\" class=\"right nowrap\">";
+            const int width = KMyMoneySettings::showLimitInfo() ? 10 : 20;
+            m_html += QString::fromUtf8("<td width=\"%1%\" class=\"right nowrap\">").arg(width);
             m_html += i18n("Balance");
             m_html += "</td>";
 
@@ -1953,6 +2005,7 @@ public:
     int m_adjustedIconSize;
     double m_devRatio;
     QTimer m_resizeRefreshTimer;
+    QTimer m_refreshDelayTimer;
     QSize m_startSize;
     bool m_endSkipWithTimerRunning;
 };
