@@ -98,7 +98,7 @@ public:
         m_accountsProxyModel->addAccountType(eMyMoney::Account::Type::Investment);
         m_accountsProxyModel->setHideEquityAccounts(false);
         m_accountsProxyModel->setHideZeroBalancedEquityAccounts(false);
-        m_accountsProxyModel->setHideZeroBalancedAccounts(KMyMoneySettings::hideZeroBalanceAccounts());
+        m_accountsProxyModel->setHideZeroBalancedAccounts(KMyMoneySettings::hideZeroBalanceAccounts() && !KMyMoneySettings::showAllAccounts());
         m_accountsProxyModel->setSourceModel(MyMoneyFile::instance()->accountsModel());
         m_accountsProxyModel->sort(AccountsModel::Column::AccountName);
         ui->m_accountComboBox->setModel(m_accountsProxyModel);
@@ -157,6 +157,7 @@ public:
         ui->m_securitiesTree->setModel(m_securitiesProxyModel);
         m_securitiesProxyModel->setSourceModel(MyMoneyFile::instance()->securitiesModel());
         m_securitiesProxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+        m_securitiesProxyModel->setSortLocaleAware(true);
 
         m_securityColumnSelector = new ColumnSelector(ui->m_securitiesTree, QStringLiteral("KInvestmentView_Securities"));
         m_securityColumnSelector->setModel(MyMoneyFile::instance()->securitiesModel());
@@ -493,7 +494,7 @@ void KInvestmentView::showEvent(QShowEvent* event)
             if (!id.isEmpty()) {
                 const auto gotoAccount = pActions[eMenu::Action::GoToAccount];
                 gotoAccount->setData(id);
-                gotoAccount->trigger();
+                MyMoneyUtils::triggerAction(gotoAccount);
             }
         });
 
@@ -691,9 +692,22 @@ void KInvestmentView::slotSettingsChanged()
         return;
     }
 
+    d->m_accountsProxyModel->setHideZeroBalancedAccounts(KMyMoneySettings::hideZeroBalanceAccounts() && !KMyMoneySettings::showAllAccounts());
+
+    // make sure current account is still visible and if not, clear out the last selected one
+    const auto indexes = d->m_accountsProxyModel->match(d->m_accountsProxyModel->index(0, 0), eMyMoney::Model::IdRole, d->m_idInvAcc, 1, Qt::MatchRecursive);
+    if (indexes.isEmpty()) {
+        d->m_idInvAcc.clear();
+        d->m_equitiesProxyModel->setHideAllEntries(true);
+        d->ui->m_accountComboBox->setSelected(QString());
+    }
+
     const bool showAllAccounts = KMyMoneySettings::showAllAccounts();
     if (d->m_equitiesProxyModel->hideClosedAccounts() == showAllAccounts) {
         d->m_equitiesProxyModel->setHideClosedAccounts(!showAllAccounts);
+        if (d->m_idInvAcc.isEmpty()) {
+            d->selectDefaultInvestmentAccount();
+        }
         d->loadAccount(d->m_idInvAcc);
     }
 }
