@@ -24,6 +24,7 @@
 // KDE Includes
 
 #include <KLocalizedString>
+#include <KMessageBox>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -33,6 +34,7 @@
 #include "icons.h"
 #include "idfilter.h"
 #include "journalmodel.h"
+#include "kmmyesno.h"
 #include "kmymoneysettings.h"
 #include "knewaccountdlg.h"
 #include "mymoneyaccount.h"
@@ -48,6 +50,7 @@
 #include "securitiesmodel.h"
 #include "splitdialog.h"
 #include "statusmodel.h"
+#include "taborder.h"
 #include "tagsmodel.h"
 #include "widgethintframe.h"
 
@@ -74,6 +77,21 @@ public:
         , payeesModel(new QSortFilterProxyModel(parent))
         , frameCollection(nullptr)
         , costCenterRequired(false)
+        , m_tabOrder(QLatin1String("multiTransactionEditor"),
+                     QStringList{
+                         QLatin1String("accountCombo"),
+                         QLatin1String("dateEdit"),
+                         QLatin1String("creditDebitEdit"),
+                         QLatin1String("payeeEdit"),
+                         QLatin1String("numberEdit"),
+                         QLatin1String("categoryCombo"),
+                         QLatin1String("costCenterCombo"),
+                         QLatin1String("tagContainer"),
+                         QLatin1String("statusCombo"),
+                         QLatin1String("memoEdit"),
+                         QLatin1String("enterButton"),
+                         QLatin1String("cancelButton"),
+                     })
     {
         accountsModel->setObjectName(QLatin1String("MultiTransactionEditor::accountsModel"));
         categoriesModel->setObjectName(QLatin1String("MultiTransactionEditor::categoriesModel"));
@@ -92,7 +110,6 @@ public:
         delete ui;
     }
 
-    void setupTabOrder();
     bool anyChanges() const;
     bool isDatePostOpeningDate(const QDate& date, const QString& accountId);
     bool checkForValidTransaction(bool doUserInteraction);
@@ -120,6 +137,7 @@ public:
     StatusModel statusModel;
     QStringList selectedJournalEntryIds;
     bool costCenterRequired;
+    TabOrder m_tabOrder;
 };
 
 bool MultiTransactionEditor::Private::anyChanges() const
@@ -297,28 +315,6 @@ void MultiTransactionEditor::Private::tagsChanged(const QStringList& tagIds)
     Q_UNUSED(tagIds)
 }
 
-void MultiTransactionEditor::Private::setupTabOrder()
-{
-    const auto defaultTabOrder = QStringList{
-        QLatin1String("accountCombo"),
-        QLatin1String("dateEdit"),
-        QLatin1String("creditDebitEdit"),
-        QLatin1String("payeeEdit"),
-        QLatin1String("numberEdit"),
-        QLatin1String("categoryCombo"),
-        QLatin1String("costCenterCombo"),
-        QLatin1String("tagContainer"),
-        QLatin1String("statusCombo"),
-        QLatin1String("memoEdit"),
-        QLatin1String("enterButton"),
-        QLatin1String("cancelButton"),
-    };
-    q->setProperty("kmm_defaulttaborder", defaultTabOrder);
-    q->setProperty("kmm_currenttaborder", q->tabOrder(QLatin1String("multiTransactionEditor"), defaultTabOrder));
-
-    q->setupTabOrder(q->property("kmm_currenttaborder").toStringList());
-}
-
 MultiTransactionEditor::MultiTransactionEditor(QWidget* parent, const QString& accountId)
     : TransactionEditorBase(parent, accountId)
     , d(new Private(this))
@@ -333,7 +329,7 @@ MultiTransactionEditor::MultiTransactionEditor(QWidget* parent, const QString& a
     setShowAccountCombo(false);
     setShowNumberWidget(false);
 
-    d->setupTabOrder();
+    d->m_tabOrder.setWidget(this);
 
     // determine order of credit and debit edit widgets
     // based on their visual order in the ledger
@@ -550,64 +546,94 @@ QStringList MultiTransactionEditor::saveTransaction(const QStringList& selectedJ
             for (const auto& journalEntryId : selectedJournalEntryIds) {
                 const auto journalIdx = journalModel->indexById(journalEntryId);
                 const auto journalEntry = journalModel->itemByIndex(journalIdx);
-                auto t = journalEntry.transaction();
-                auto sp = journalEntry.split();
-                MyMoneySplit csp;
+                auto transaction = journalEntry.transaction();
+                auto selectedSplit = journalEntry.split();
+                MyMoneySplit counterSplit;
 
-                if (t.splitCount() == 2) {
-                    for (auto split : t.splits()) {
-                        if (split.id() != sp.id()) {
-                            csp = split;
+                if (transaction.splitCount() == 2) {
+                    for (auto split : transaction.splits()) {
+                        if (split.id() != selectedSplit.id()) {
+                            counterSplit = split;
                             break;
                         }
                     }
                 }
 
+                // we take care of the category first because it
+                // may create a split which is needed in the
+                // next steps
+                if (!d->ui->categoryCombo->getSelected().isEmpty()) {
+                    if (!counterSplit.id().isEmpty()) {
+                        counterSplit.setAccountId(d->ui->categoryCombo->getSelected());
+                        transaction.modifySplit(counterSplit);
+
+                    } else {
+                        counterSplit = selectedSplit;
+                        counterSplit.clearId();
+                        counterSplit.setValue(-counterSplit.value());
+                        /// @todo make assignment multi currency safe. For now, we
+                        /// just dump out a debug message in case both securities are
+                        /// not the same
+                        counterSplit.setShares(-counterSplit.shares());
+                        counterSplit.setAccountId(d->ui->categoryCombo->getSelected());
+                        if (!splitsUseSameCurrency(selectedSplit, counterSplit)) {
+                            qDebug() << "MultiTransactionEditor does not support multiple currencies yet";
+                        }
+                        counterSplit.setReconcileDate(QDate());
+                        counterSplit.setReconcileFlag(eMyMoney::Split::State::Unknown);
+                        counterSplit.setBankID(QString());
+                        counterSplit.setAction(QString());
+                        counterSplit.setNumber(QString());
+                        transaction.addSplit(counterSplit);
+                    }
+                }
+
                 if (!d->ui->dateEdit->isNull()) {
-                    t.setPostDate(d->ui->dateEdit->date());
+                    transaction.setPostDate(d->ui->dateEdit->date());
                 }
                 if (!d->ui->statusCombo->currentText().isEmpty()) {
                     const auto idx = d->statusModel.index(d->ui->statusCombo->currentIndex(), 0);
-                    sp.setReconcileFlag(idx.data(eMyMoney::Model::SplitReconcileStateRole).value<eMyMoney::Split::State>());
-                    t.modifySplit(sp);
+                    selectedSplit.setReconcileFlag(idx.data(eMyMoney::Model::SplitReconcileStateRole).value<eMyMoney::Split::State>());
+                    transaction.modifySplit(selectedSplit);
                 }
                 if (!d->ui->payeeEdit->lineEdit()->text().isEmpty()) {
                     const auto payeeRow = d->ui->payeeEdit->currentIndex();
                     const auto payeeIdx = d->payeesModel->index(payeeRow, 0);
                     const auto payeeId = payeeIdx.data(eMyMoney::Model::IdRole).toString();
-                    sp.setPayeeId(payeeId);
-                    t.modifySplit(sp);
-                    if (!csp.id().isEmpty()) {
-                        csp.setPayeeId(payeeId);
-                        t.modifySplit(csp);
+                    selectedSplit.setPayeeId(payeeId);
+                    transaction.modifySplit(selectedSplit);
+                    if (!counterSplit.id().isEmpty()) {
+                        counterSplit.setPayeeId(payeeId);
+                        transaction.modifySplit(counterSplit);
                     }
                 }
-                if (!d->ui->categoryCombo->getSelected().isEmpty()) {
-                    if (!csp.id().isEmpty()) {
-                        csp.setAccountId(d->ui->categoryCombo->getSelected());
-                        t.modifySplit(csp);
-                    } else {
-                        csp = sp;
-                        csp.clearId();
-                        csp.setValue(-csp.value());
-                        /// @todo make assignment multi currency safe. For now, we
-                        /// just dump out a debug message in case both securities are
-                        /// not the same
-                        csp.setShares(-csp.shares());
-                        csp.setAccountId(d->ui->categoryCombo->getSelected());
-                        if (!splitsUseSameCurrency(sp, csp)) {
-                            qDebug() << "MultiTransactionEditor does not support multiple currencies yet";
+                if (!d->ui->tagContainer->selectedTags().isEmpty()) {
+                    auto currentTagList = counterSplit.tagIdList();
+                    const auto newTagList = d->ui->tagContainer->selectedTags();
+                    for (const auto& newTag : newTagList) {
+                        if (!currentTagList.contains(newTag)) {
+                            currentTagList.append(newTag);
                         }
-                        csp.setReconcileDate(QDate());
-                        csp.setReconcileFlag(eMyMoney::Split::State::Unknown);
-                        csp.setBankID(QString());
-                        csp.setAction(QString());
-                        csp.setNumber(QString());
-                        t.addSplit(csp);
+                    }
+                    if (!counterSplit.id().isEmpty()) {
+                        counterSplit.setTagIdList(currentTagList);
+                        transaction.modifySplit(counterSplit);
                     }
                 }
 
-                file->modifyTransaction(t);
+                if (!d->ui->memoEdit->toPlainText().isEmpty()) {
+                    const auto memo = d->ui->memoEdit->toPlainText().trimmed();
+                    selectedSplit.setMemo(memo);
+                    if (!counterSplit.id().isEmpty()) {
+                        const auto counterAccountIdx = file->accountsModel()->indexById(counterSplit.accountId());
+                        if (MyMoneyAccount::isIncomeExpense(counterAccountIdx.data(eMyMoney::Model::AccountTypeRole).value<eMyMoney::Account::Type>())) {
+                            counterSplit.setMemo(memo);
+                            transaction.modifySplit(counterSplit);
+                        }
+                    }
+                    transaction.modifySplit(selectedSplit);
+                }
+                file->modifyTransaction(transaction);
             }
             ft.commit();
         } catch (const MyMoneyException& e) {
@@ -688,7 +714,7 @@ void MultiTransactionEditor::setReadOnly(bool readOnly)
     }
 }
 
-void MultiTransactionEditor::setupUi(QWidget* parent)
+QWidget* MultiTransactionEditor::setupUi(QWidget* parent)
 {
     if (d->tabOrderUi == nullptr) {
         d->tabOrderUi = new Ui::NewTransactionEditor;
@@ -696,11 +722,12 @@ void MultiTransactionEditor::setupUi(QWidget* parent)
     d->tabOrderUi->setupUi(parent);
     d->tabOrderUi->accountLabel->setVisible(false);
     d->tabOrderUi->accountCombo->setVisible(false);
+    return this;
 }
 
 void MultiTransactionEditor::storeTabOrder(const QStringList& tabOrder)
 {
-    TransactionEditorBase::storeTabOrder(QLatin1String("multiTransactionEditor"), tabOrder);
+    d->m_tabOrder.setTabOrder(tabOrder);
 }
 
 void MultiTransactionEditor::slotSettingsChanged()
@@ -767,5 +794,22 @@ QString MultiTransactionEditor::errorMessage() const
 
 bool MultiTransactionEditor::isTransactionDataValid() const
 {
+    if (!d->ui->memoEdit->toPlainText().isEmpty()) {
+        if (d->ui->memoEdit->toPlainText().trimmed().isEmpty()) {
+            const auto rc = KMessageBox::questionTwoActions(
+                parentWidget(),
+                i18n("You have entered only spaces in the memo field which will clear the existing memo content. Do you really want to do this?"),
+                i18n("Clear memo"),
+                KMMYesNo::yes(),
+                KMMYesNo::no(),
+                QLatin1String("ClearMemo"));
+            return rc == KMessageBox::PrimaryAction;
+        }
+    }
     return true;
 }
+
+TabOrder* MultiTransactionEditor::tabOrder() const
+{
+    return &d->m_tabOrder;
+}
