@@ -140,6 +140,7 @@ public:
     void updateVAT(TaxValueChange amountChanged);
     MyMoneyMoney removeVatSplit();
     MyMoneyMoney splitsSum() const;
+    bool hasCalculatedSplit() const;
     void defaultCategoryAssignment();
     void loadTransaction(QModelIndex idx);
     MyMoneySplit prepareSplit(const MyMoneySplit& sp);
@@ -166,6 +167,7 @@ public:
     KMyMoneyAccountComboSplitHelper* m_splitHelper;
     TabOrder* m_externalTabOrder;
     TabOrder m_tabOrder;
+    QString m_initialCheckNumber;
 };
 
 void NewTransactionEditor::Private::updateWidgetAccess()
@@ -235,7 +237,7 @@ bool NewTransactionEditor::Private::checkForValidAmount()
     if (!difference.isZero()) {
         if (splitModel.rowCount() == 0) {
             WidgetHintFrame::show(ui->categoryCombo, i18nc("@info:tooltip", "The transaction is missing a category assignment."));
-        } else {
+        } else if (!hasCalculatedSplit()) {
             WidgetHintFrame::show(
                 ui->creditDebitEdit,
                 i18nc("@info:tooltip", "The amount entered is different from the sum of all splits by %1.", difference.formatMoney(m_account.fraction())));
@@ -457,19 +459,10 @@ bool NewTransactionEditor::Private::numberChanged(const QString& newNumber)
 {
     bool rc = true; // number did change
     WidgetHintFrame::hide(ui->numberEdit);
-    if (!newNumber.isEmpty()) {
-        auto model = MyMoneyFile::instance()->journalModel();
-        const QModelIndexList list = model->match(model->index(0, 0), eMyMoney::Model::SplitNumberRole,
-                                     QVariant(newNumber),
-                                     -1,                         // all splits
-                                     Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive | Qt::MatchRecursive));
-        for (const auto& idx : list) {
-            if (idx.data(eMyMoney::Model::SplitAccountIdRole).toString() == m_account.id()
-                && idx.data(eMyMoney::Model::JournalTransactionIdRole).toString().compare(m_transaction.id())) {
-                WidgetHintFrame::show(ui->numberEdit, i18n("The check number <b>%1</b> has already been used in this account.", newNumber));
-                rc = false;
-                break;
-            }
+    if (!newNumber.isEmpty() && (newNumber != m_initialCheckNumber)) {
+        if (MyMoneyFile::instance()->isCheckNumberInUse(m_account.id(), newNumber)) {
+            WidgetHintFrame::show(ui->numberEdit, i18n("The check number <b>%1</b> has already been used in this account.", newNumber));
+            rc = false;
         }
     }
     return rc;
@@ -515,11 +508,10 @@ void NewTransactionEditor::Private::payeeChanged(int payeeIndex)
     const AutoFillMethod autoFillMethod = static_cast<AutoFillMethod>(KMyMoneySettings::autoFillTransaction());
 
     // we have a new payee assigned to this transaction.
-    // in case there is no category assigned, no value entered and no
-    // memo available, we search for the last transaction of this payee
+    // in case there is no category assigned for a new transaction,
+    // we search for the last transaction of this payee
     // in the selected account.
-    if (m_transaction.id().isEmpty() && (splitModel.rowCount() == 0) && !ui->creditDebitEdit->haveValue() && ui->memoEdit->toPlainText().isEmpty()
-        && !m_account.id().isEmpty() && (autoFillMethod != AutoFillMethod::NoAutoFill)) {
+    if (m_transaction.id().isEmpty() && (splitModel.rowCount() == 0) && (autoFillMethod != AutoFillMethod::NoAutoFill)) {
         // if we got here, we have to autofill. Because we will open a dialog,
         // we simply postpone the call until we reach the main event loop. We
         // do this because running the dialog directly has some unknown influence
@@ -538,16 +530,20 @@ void NewTransactionEditor::Private::payeeChanged(int payeeIndex)
 
 void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
 {
+    // Capture user's amount immediately at function entry (before any processing)
+    const auto userAmountFilled = ui->creditDebitEdit->haveValue();
+    const auto userAmount = ui->creditDebitEdit->value();
+    const auto userShares = ui->creditDebitEdit->shares();
     struct uniqTransaction {
         QString journalEntryId;
-        MyMoneyTransaction transaction;
+        MyMoneyMoney amount;
         int matches;
     };
 
     /**
      * Sum up all splits for the given account in the transaction
      */
-    auto shares = [&](const MyMoneyTransaction& t, const QString& accountId) {
+    auto sumOfShares = [&](const MyMoneyTransaction& t, const QString& accountId) {
         MyMoneyMoney result;
         for (const auto& split : t.splits()) {
             if (split.accountId() == accountId) {
@@ -572,22 +568,24 @@ void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
         // collect the journal entries and see if we have any duplicates
         for (const auto& journalEntryId : journalEntryIds) {
             const auto journalEntry = journalModel->itemById(journalEntryId);
+            const auto accountSignature = journalEntry.transaction().accountSignature();
+            const auto sharesSum = sumOfShares(journalEntry.transaction(), m_account.id());
             int cnt = 0;
             QMap<QString, struct uniqTransaction>::iterator it_u;
             do {
-                QString ukey = QString("%1-%2").arg(journalEntry.transaction().accountSignature()).arg(cnt);
+                const QString ukey = QString("%1-%2").arg(accountSignature, cnt);
                 it_u = uniqList.find(ukey);
                 if (it_u == uniqList.end()) {
                     uniqList[ukey].journalEntryId = journalEntryId;
-                    uniqList[ukey].transaction = journalEntry.transaction();
+                    uniqList[ukey].amount = sumOfShares(journalEntry.transaction(), m_account.id());
                     uniqList[ukey].matches = 1;
 
                 } else if (autoFillMethod == AutoFillMethod::AutoFillWithClosestInValue) {
                     // we already have a transaction with this signature. we must
                     // now check, if we should really treat it as a duplicate according
                     // to the value comparison delta.
-                    MyMoneyMoney s1 = shares(((*it_u).transaction), m_account.id());
-                    MyMoneyMoney s2 = shares(journalEntry.transaction(), m_account.id());
+                    MyMoneyMoney s1 = (*it_u).amount;
+                    MyMoneyMoney s2 = sharesSum;
                     if (s2.abs() > s1.abs()) {
                         MyMoneyMoney t(s1);
                         s1 = s2;
@@ -601,12 +599,12 @@ void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
                     }
                     if (diff.isPositive() && diff <= MyMoneyMoney(KMyMoneySettings::autoFillDifference(), 100)) {
                         uniqList[ukey].journalEntryId = journalEntryId;
-                        uniqList[ukey].transaction = journalEntry.transaction();
+                        uniqList[ukey].amount = sumOfShares(journalEntry.transaction(), m_account.id());
                         break; // end while loop
                     }
                 } else if (autoFillMethod == AutoFillMethod::AutoFillWithMostOftenUsed) {
                     uniqList[ukey].journalEntryId = journalEntryId;
-                    uniqList[ukey].transaction = journalEntry.transaction();
+                    uniqList[ukey].amount = sumOfShares(journalEntry.transaction(), m_account.id());
                     (*it_u).matches++;
                     break; // end while loop
                 }
@@ -620,9 +618,11 @@ void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
             dlg->setWindowTitle(i18nc("@title:window Autofill selection dialog", "Select autofill transaction"));
 
             QMap<QString, struct uniqTransaction>::const_iterator it_u;
+            QStringList journalEntryIdCollection;
             for (it_u = uniqList.cbegin(); it_u != uniqList.cend(); ++it_u) {
-                dlg->addTransaction((*it_u).journalEntryId);
+                journalEntryIdCollection << (*it_u).journalEntryId;
             }
+            dlg->addTransactions(journalEntryIdCollection);
 
             // Sort by
             // - ascending post date
@@ -648,19 +648,12 @@ void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
             // keep data we don't want to change by loading
             const auto postDate = ui->dateEdit->date();
             const auto number = ui->numberEdit->text();
+            const auto memo = ui->memoEdit->toPlainText();
+
             // now load the existing transaction into the editor
             auto index = MyMoneyFile::instance()->journalModel()->indexById(journalEntryId);
             loadTransaction(index);
 
-            // restore data we don't want to change by loading
-            ui->dateEdit->setDate(postDate);
-
-            if (ui->numberEdit->isVisible() && !number.isEmpty()) {
-                ui->numberEdit->setText(number);
-            } else if (!m_split.number().isEmpty()) {
-                ui->numberEdit->setText(KMyMoneyUtils::nextFreeCheckNumber(m_account));
-            }
-
             // make sure to really create a new transaction
             m_transaction.clearId();
             ui->statusCombo->setCurrentIndex(static_cast<int>(eMyMoney::Split::State::NotReconciled));
@@ -680,8 +673,36 @@ void NewTransactionEditor::Private::autoFillTransaction(const QString& payeeId)
                 // copy payee information to second split if there are only two splits
                 if (splitModel.rowCount() == 1) {
                     splitModel.setData(idx, payeeId, eMyMoney::Model::SplitPayeeIdRole);
+                    if (!memo.isEmpty()) {
+                        splitModel.setData(idx, memo, eMyMoney::Model::SplitMemoRole);
+                    }
+                    // Don't update split amounts - let them come from the loaded transaction
+                    // The UI amount preservation happens separately
                 }
             }
+            // restore data we don't want to change by loading
+            ui->dateEdit->setDate(postDate);
+
+            if (ui->numberEdit->isVisible() && !number.isEmpty()) {
+                ui->numberEdit->setText(number);
+            } else if (!m_split.number().isEmpty() && (m_account.accountType() == eMyMoney::Account::Type::Checkings)) {
+                ui->numberEdit->setText(MyMoneyFile::instance()->nextCheckNumber(m_account.id()));
+            }
+
+            // If user had entered an amount, restore it (loadTransaction would have overwritten it)
+            if (userAmountFilled) {
+                ui->creditDebitEdit->setValue(userAmount);
+                ui->creditDebitEdit->setShares(userShares);
+            }
+
+            // if the user already entered a memo we use it
+            if (!memo.isEmpty()) {
+                ui->memoEdit->setPlainText(memo);
+            }
+
+            updateWidgetState();
+            updateWidgetAccess();
+            checkForValidAmount();
         }
     }
 
@@ -720,11 +741,24 @@ bool NewTransactionEditor::Private::tagsChanged(const QStringList& ids)
     return true;
 }
 
+bool NewTransactionEditor::Private::hasCalculatedSplit() const
+{
+    const auto rows = splitModel.rowCount();
+    MyMoneyMoney value;
+    for (int row = 0; row < rows; ++row) {
+        const auto idx = splitModel.index(row, 0);
+        if (idx.data(eMyMoney::Model::SplitValueRole).value<MyMoneyMoney>().isAutoCalc()) {
+            return true;
+        }
+    }
+    return false;
+}
+
 MyMoneyMoney NewTransactionEditor::Private::splitsSum() const
 {
     const auto rows = splitModel.rowCount();
     MyMoneyMoney value;
-    for(int row = 0; row < rows; ++row) {
+    for (int row = 0; row < rows; ++row) {
         const auto idx = splitModel.index(row, 0);
         value += idx.data(eMyMoney::Model::SplitValueRole).value<MyMoneyMoney>();
     }
@@ -952,12 +986,22 @@ void NewTransactionEditor::Private::updateVAT(TaxValueChange amountChanged)
     MyMoneyFile::instance()->updateVAT(t);
 
     // keep the split model in sync with the new data
+    MyMoneySplit accountSplit;
     splitModel.unload();
     for (const auto& split : t.splits()) {
         if ((split.accountId() == taxId) || split.accountId() == categoryId) {
             splitModel.appendSplit(split);
+        } else {
+            accountSplit = split;
         }
     }
+
+    // In case the category is based on the net amount entry, we need to update
+    // the widgets to show the gross amount for the account.  In case
+    // the category is based on gross amount entry setting the same value
+    // does not hurt.
+    ui->creditDebitEdit->setValue(accountSplit.value(), true);
+    ui->creditDebitEdit->setShares(accountSplit.shares());
 }
 
 void NewTransactionEditor::Private::defaultCategoryAssignment()
@@ -990,6 +1034,7 @@ void NewTransactionEditor::Private::loadTransaction(QModelIndex idx)
     // keep a copy of the transaction and split
     m_transaction = MyMoneyFile::instance()->journalModel()->itemByIndex(idx).transaction();
     m_split = MyMoneyFile::instance()->journalModel()->itemByIndex(idx).split();
+    m_initialCheckNumber = m_split.number();
     const auto list = idx.model()->match(idx.model()->index(0, 0),
                                          eMyMoney::Model::JournalTransactionIdRole,
                                          idx.data(eMyMoney::Model::JournalTransactionIdRole),
@@ -1013,6 +1058,10 @@ void NewTransactionEditor::Private::loadTransaction(QModelIndex idx)
     // because they are not yet set (d->ui->creditDebitEdit)
     QSignalBlocker blocker(splitModel);
 
+    // make sure that the split model is empty when a new
+    // transaction is loaded
+    splitModel.unload();
+
     for (const auto& splitIdx : list) {
         if (selectedSplitRow == splitIdx.row()) {
             ui->dateEdit->setDate(splitIdx.data(eMyMoney::Model::TransactionPostDateRole).toDate());
@@ -1060,8 +1109,11 @@ void NewTransactionEditor::Private::loadTransaction(QModelIndex idx)
 
     // then setup the amount widget and update the state
     // of all other widgets
-    ui->creditDebitEdit->setValue(amountValue);
-    ui->creditDebitEdit->setShares(amountShares);
+    // Only set amount if user hasn't already entered one
+    if (!ui->creditDebitEdit->haveValue()) {
+        ui->creditDebitEdit->setValue(amountValue);
+        ui->creditDebitEdit->setShares(amountShares);
+    }
 
     updateWidgetState();
     updateWidgetAccess();
@@ -1190,13 +1242,30 @@ NewTransactionEditor::NewTransactionEditor(QWidget* parent, const QString& accou
 
     // make sure that there is no selection left in the background
     // in case there is no text in the edit field
-    connect(d->ui->payeeEdit->lineEdit(), &QLineEdit::textEdited, [&](const QString& txt) {
+    connect(d->ui->payeeEdit->lineEdit(), &QLineEdit::textEdited, this, [&](const QString& txt) {
         if (txt.isEmpty()) {
             d->ui->payeeEdit->setCurrentIndex(-1);
         }
     });
 
-    connect(d->ui->categoryCombo->lineEdit(), &QLineEdit::textEdited, [&](const QString& txt) {
+    connect(
+        d->ui->payeeEdit->lineEdit(),
+        &QLineEdit::textEdited,
+        this,
+        [&](const QString& txt) {
+            if (!txt.isEmpty()) {
+                // when the user types something, select the first entry in the popup
+                const auto view = d->ui->payeeEdit->completer()->popup();
+                const auto viewsModel = view->model();
+                // prevent that setting the current index propagates the full
+                // name into the edit widget
+                QSignalBlocker blocker(view->selectionModel());
+                view->setCurrentIndex(viewsModel->index(0, 0));
+            }
+        },
+        Qt::QueuedConnection);
+
+    connect(d->ui->categoryCombo->lineEdit(), &QLineEdit::textEdited, this, [&](const QString& txt) {
         if (txt.isEmpty()) {
             d->ui->categoryCombo->setSelected(QString());
         }
@@ -1260,6 +1329,7 @@ NewTransactionEditor::NewTransactionEditor(QWidget* parent, const QString& accou
 
     // handle some events in certain conditions different from default
     d->ui->payeeEdit->installEventFilter(this);
+    d->ui->payeeEdit->completer()->popup()->installEventFilter(this);
     d->ui->costCenterCombo->installEventFilter(this);
     d->ui->tagContainer->tagCombo()->installEventFilter(this);
     d->ui->categoryCombo->installEventFilter(this);
@@ -1338,7 +1408,7 @@ void NewTransactionEditor::loadSchedule(const MyMoneySchedule& schedule, Schedul
         QSignalBlocker splitModelSignalBlocker(d->splitModel);
 
         // block the signals sent out from the payee edit widget so that
-        // the autofill logic is not trigger when loading the schdule
+        // the autofill logic is not triggered when loading the schedule
         QSignalBlocker autoFillSignalBlocker(d->ui->payeeEdit);
 
         for (const auto& split : d->m_transaction.splits()) {
@@ -1401,6 +1471,7 @@ void NewTransactionEditor::loadSchedule(const MyMoneySchedule& schedule, Schedul
         d->checkForValidAmount();
 
         d->m_splitHelper->updateWidget();
+        d->m_initialCheckNumber.clear();
     }
 }
 
@@ -1435,6 +1506,7 @@ void NewTransactionEditor::loadTransaction(const QModelIndex& index)
 
         d->m_split = MyMoneySplit();
         d->m_split.setAccountId(d->m_account.id());
+        d->m_initialCheckNumber.clear();
         const auto lastUsedPostDate = KMyMoneySettings::lastUsedPostDate();
         if (lastUsedPostDate.isValid()) {
             d->ui->dateEdit->setDate(lastUsedPostDate.date());
@@ -1442,6 +1514,11 @@ void NewTransactionEditor::loadTransaction(const QModelIndex& index)
             d->ui->dateEdit->setDate(QDate::currentDate());
         }
 
+        // in case user selected to fill number field with next number ...
+        if ((d->m_account.accountType() == eMyMoney::Account::Type::Checkings) && KMyMoneySettings::autoIncCheckNumber()) {
+            d->ui->numberEdit->setText(MyMoneyFile::instance()->nextCheckNumber(d->m_account.id()));
+        }
+
         d->ui->creditDebitEdit->setSharesCommodity(commodity);
         // the default exchange rate is 1 so we don't need to set it here
 
@@ -1452,7 +1529,6 @@ void NewTransactionEditor::loadTransaction(const QModelIndex& index)
     setInitialFocus();
 }
 
-
 void NewTransactionEditor::editSplits()
 {
     d->editSplits() == QDialog::Accepted ? acceptEdit() : reject();
@@ -1591,20 +1667,30 @@ MyMoneyTransaction NewTransactionEditor::transaction() const
 
 QStringList NewTransactionEditor::saveTransaction(const QStringList& selectedJournalEntries)
 {
+    const auto file = MyMoneyFile::instance();
     auto t = transaction();
 
     auto selection(selectedJournalEntries);
-    connect(MyMoneyFile::instance()->journalModel(), &JournalModel::idChanged, this, [&](const QString& currentId, const QString& previousId) {
+    connect(file->journalModel(), &JournalModel::idChanged, this, [&](const QString& currentId, const QString& previousId) {
         selection.replaceInStrings(previousId, currentId);
     });
 
     MyMoneyFileTransaction ft;
     try {
         if (t.id().isEmpty()) {
-            MyMoneyFile::instance()->addTransaction(t);
+            file->addTransaction(t);
+            selection = journalEntrySelection(t.id(), d->m_account.id());
         } else {
             t.setImported(false);
-            MyMoneyFile::instance()->modifyTransaction(t);
+            file->modifyTransaction(t);
+        }
+        // in case we have a check number
+        const auto highestCheckNumberUsed = file->highestCheckNumberUsed(d->m_account.id());
+        if (highestCheckNumberUsed.compare(QLatin1String("0"))) {
+            // update property on account
+            d->m_account = file->account(d->m_account.id());
+            d->m_account.setValue(QLatin1String("lastNumberUsed"), highestCheckNumberUsed);
+            file->modifyAccount(d->m_account);
         }
         ft.commit();
 
@@ -1628,6 +1714,18 @@ bool NewTransactionEditor::eventFilter(QObject* o, QEvent* e)
                 }
 
             } else if (o == d->ui->payeeEdit) {
+                // in case the popup for the payee is visible we need to copy the
+                // selected text into the combobox widget so that the payee can
+                // be found in the list
+                if (combobox->lineEdit()->completer()->popup()->isVisible()) {
+                    const auto view = combobox->lineEdit()->completer()->popup();
+                    const auto model = view->selectionModel();
+                    const auto selectedRows = model->selectedRows();
+                    if (!selectedRows.isEmpty()) {
+                        combobox->setCurrentText(selectedRows.at(0).data(eMyMoney::Model::PayeeNameRole).toString());
+                    }
+                }
+
                 if (needCreatePayee(combobox)) {
                     createPayee(combobox);
 
@@ -1653,6 +1751,21 @@ bool NewTransactionEditor::eventFilter(QObject* o, QEvent* e)
             }
         }
     }
+    if (o == d->ui->payeeEdit->completer()->popup()) {
+        if (e->type() == QEvent::KeyPress) {
+            auto kev = static_cast<QKeyEvent*>(e);
+            if (kev->key() == Qt::Key_Enter || kev->key() == Qt::Key_Return) {
+                const auto view = d->ui->payeeEdit->completer()->popup();
+                // get the current index and toggle it once to
+                // an invalid one so that the signal is
+                // emitted to fill the full name into
+                // the payee edit widget
+                const auto idx = view->currentIndex();
+                view->setCurrentIndex(QModelIndex());
+                view->setCurrentIndex(idx);
+            }
+        }
+    }
     return TransactionEditorBase::eventFilter(o, e);
 }
 
