@@ -206,15 +206,6 @@ public:
         q->setMinimumHeight(height);
     }
 
-    void cut()
-    {
-        Q_Q(AmountEdit);
-        // only cut if parts of the text are selected
-        if (q->hasSelectedText() && (q->text() != q->selectedText())) {
-            cut();
-        }
-    }
-
     bool hasMultipleCurrencies() const
     {
         return m_sharesCommodity.id().compare(m_valueCommodity.id());
@@ -332,7 +323,7 @@ public:
             if (q->isEnabled() && !txt.isEmpty()) {
                 ensureFractionalPart(widgetTextCache, state);
                 // ensureFractionalPart is used to add digits but
-                // ist should not remove some. If that's the
+                // it should not remove some. If that's the
                 // case we revert what it has done
                 if (widgetTextCache.length() < txt.length()) {
                     widgetTextCache = txt;
@@ -522,7 +513,7 @@ void AmountEdit::focusOutEvent(QFocusEvent* event)
     Q_D(AmountEdit);
     QLineEdit::focusOutEvent(event);
 
-    if (event->reason() != Qt::ActiveWindowFocusReason) {
+    if ((event->reason() != Qt::ActiveWindowFocusReason) && !isReadOnly()) {
         // make sure we have a zero value in case the current text
         // is empty but this is not allowed
         if (text().isEmpty() && !d->m_allowEmpty) {
@@ -546,87 +537,116 @@ void AmountEdit::focusOutEvent(QFocusEvent* event)
 
 void AmountEdit::keyPressEvent(QKeyEvent* event)
 {
-    Q_D(AmountEdit);
-    switch(event->key()) {
-    case Qt::Key_Plus:
-    case Qt::Key_Minus:
-        d->cut();
-        if (text().length() == 0) {
+    auto suppressVerticalMovement = [&](QKeyEvent* ev) {
+        switch (ev->key()) {
+        case Qt::Key_Up:
+        case Qt::Key_Down:
+        case Qt::Key_PageUp:
+        case Qt::Key_PageDown:
+            ev->accept();
+            break;
+        default:
             break;
         }
-        // in case of '-' we do not enter the calculator when
-        // the current position is the beginning and there is
-        // no '-' sign at the first position.
-        if (event->key() == Qt::Key_Minus) {
-            if (cursorPosition() == 0 && text().at(0) != '-') {
+    };
+
+    Q_D(AmountEdit);
+    if (!isReadOnly()) {
+        switch (event->key()) {
+        case Qt::Key_Plus:
+        case Qt::Key_Minus:
+            if (text().length() == 0) {
                 break;
             }
-        }
-        // intentional fall through
-
-    case Qt::Key_Slash:
-    case Qt::Key_Asterisk:
-    case Qt::Key_Percent:
-        d->cut();
-        d->calculatorOpen(event);
-        return;
-
-    case Qt::Key_Return:
-    case Qt::Key_Escape:
-    case Qt::Key_Enter:
-        break;
-
-    case Qt::Key_Space:
-        if (event->modifiers() == Qt::ControlModifier) {
-            event->accept();
-            d->m_currencyButton->animateClick();
-            return;
-        }
-        break;
-
-    default:
-        // make sure to use the locale's decimalPoint when the
-        // keypad comma/dot is pressed
-        QString keyText = event->text();
-        int key = event->key();
-        if (event->modifiers() & Qt::KeypadModifier) {
-            if ((key == Qt::Key_Period) || (key == Qt::Key_Comma)) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                key = QLocale().decimalPoint().unicode();
-#else
-                key = QLocale().decimalPoint().at(0).unicode();
-#endif
-                keyText = QLocale().decimalPoint();
+            // in case of '-' we do not enter the calculator when
+            // the current position is the beginning and there is
+            // no '-' sign at the first position.
+            if (event->key() == Qt::Key_Minus) {
+                if (cursorPosition() == 0 && text().at(0) != '-') {
+                    break;
+                }
             }
-        }
-        // create a (possibly adjusted) copy of the event
-        QKeyEvent newEvent(event->type(),
-                           key,
-                           event->modifiers(),
-                           event->nativeScanCode(),
-                           event->nativeVirtualKey(),
-                           event->nativeModifiers(),
-                           keyText,
-                           event->isAutoRepeat(),
-                           event->count());
+            // intentional fall through
 
-        // in case all text is selected and the user presses the decimal point
-        // we fill the widget with the leading "0". The outcome of this will be
-        // that the widget then contains "0.".
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if ((newEvent.key() == QLocale().decimalPoint().unicode()) && (selectedText() == text())) {
-#else
-        if ((newEvent.key() == QLocale().decimalPoint().at(0).unicode()) && (selectedText() == text())) {
-#endif
-            QLineEdit::setText(QLatin1String("0"));
+        case Qt::Key_Slash:
+        case Qt::Key_Asterisk:
+        case Qt::Key_Percent:
+            d->calculatorOpen(event);
+            return;
+
+        case Qt::Key_Return:
+        case Qt::Key_Escape:
+        case Qt::Key_Enter:
+            break;
+
+        case Qt::Key_Space:
+            if (event->modifiers() == Qt::ControlModifier) {
+                event->accept();
+                d->m_currencyButton->animateClick();
+                return;
+            }
+            break;
+
+        default:
+            // make sure to use the locale's decimalPoint when the
+            // keypad comma/dot is pressed
+            QString keyText = event->text();
+            int key = event->key();
+            if (event->modifiers() & Qt::KeypadModifier) {
+                if ((key == Qt::Key_Period) || (key == Qt::Key_Comma)) {
+                    key = MyMoneyMoney::decimalSeparator().unicode();
+                    keyText = MyMoneyMoney::decimalSeparator();
+                }
+                // create a (possibly adjusted) copy of the event
+                QKeyEvent newEvent(event->type(),
+                                   key,
+                                   event->modifiers(),
+                                   event->nativeScanCode(),
+                                   event->nativeVirtualKey(),
+                                   event->nativeModifiers(),
+                                   keyText,
+                                   event->isAutoRepeat(),
+                                   event->count());
+
+                // in case all text is selected and the user presses the decimal point
+                // we fill the widget with the leading "0". The outcome of this will be
+                // that the widget then contains "0.".
+                if ((newEvent.key() == MyMoneyMoney::decimalSeparator().unicode()) && (selectedText() == text())) {
+                    QLineEdit::setText(QLatin1String("0"));
+                }
+                QLineEdit::keyPressEvent(&newEvent);
+
+                // in case the key was not handled by the base class
+                // we have to make sure that we do not report any
+                // vertical movement to upper layers
+                suppressVerticalMovement(&newEvent);
+
+                // propagate acceptance state to the event that
+                // is visible to the caller
+                event->setAccepted(newEvent.isAccepted());
+                return;
+            }
+            break;
         }
-        QLineEdit::keyPressEvent(&newEvent);
-        return;
     }
 
     // in case we have not processed anything, we
     // need to call the base class implementation
+    // we keep the current content so we can check
+    // if the key pressure did change and was consumed
+    const auto oldContent = text();
     QLineEdit::keyPressEvent(event);
+
+    // in case the key was not handled by the base class
+    // we have to make sure that we do not report any
+    // vertical movement to upper layers
+    suppressVerticalMovement(event);
+
+    // if no change, we assume no consumption and
+    // propagate the event to parent widgets. This
+    // allows shortcuts to be handled in upstream
+    // widgets.
+    event->setAccepted(event->isAccepted() || (text() != oldContent));
 }
 
 void AmountEdit::setPrecision(const int prec, bool forceUpdate)
@@ -816,6 +836,7 @@ void AmountEdit::slotCalculatorResult()
         MyMoneyMoney amount(d->m_calculator->result());
         amount = d->adjustToPrecision(d->m_state, amount);
         setText(amount.formatMoney(QString(), d->precision(d->m_state), false));
+        Q_EMIT amountChanged();
     }
 }
 
