@@ -192,3 +192,30 @@ void KMyMoneyAccountTreeView::selectionChanged(const QItemSelection &selected, c
     // since no object was selected reset the object selection
     Q_EMIT requestSelectionChange(selections);
 }
+
+void KMyMoneyAccountTreeView::resizeEvent(QResizeEvent* event)
+{
+    KMyMoneyTreeView::resizeEvent(event);
+
+    // returns either the column number of the single visible columnn or -1
+    auto singleColumn = [this]() -> int {
+        const auto headerView = this->QTreeView::header();
+        const auto columns = headerView->count();
+        auto visibleColumn = -1;
+        for (int column = 0; column < columns; ++column) {
+            if (!headerView->isSectionHidden(column)) {
+                if (visibleColumn != -1) {
+                    return -1;
+                }
+                visibleColumn = column;
+            }
+        }
+        return visibleColumn;
+    };
+
+    // make sure that if only one column is visible that it takes the whole width
+    const auto visibleColumn = singleColumn();
+    if (visibleColumn != -1) {
+        header()->resizeSection(visibleColumn, event->size().width());
+    }
+}
