@@ -48,7 +48,7 @@ public:
         m_sections.resize(3);
         const auto format(q->locale().dateFormat(QLocale::ShortFormat).toLower());
 
-        for (int pos = 0; pos < format.length(); ++pos) {
+        for (int pos = 0; (pos < format.length()) && (sectionIndex < 3); ++pos) {
             const auto ch = format[pos];
             ++sectionSize;
             if (ch == QLatin1Char('d')) {
@@ -61,25 +61,38 @@ public:
                 m_sections[sectionIndex] = QDateTimeEdit::YearSection;
                 lastWasDelimiter = false;
             } else {
+                if (!lastWasDelimiter) {
+                    ++sectionIndex;
+                    sectionSize = 0;
+                }
                 // in case we detect multiple delimiters in row, we
                 // only keep the last one. E.g. in "dd. MMM. yyyy" the
                 // space is the delimiter and the dot is a fill character
                 if (lastWasDelimiter && lastDelimiterAdded) {
+                    const auto invalidDelim = m_validDelims.at(m_validDelims.length() - 1);
+                    if (!m_invalidDelims.contains(invalidDelim)) {
+                        m_invalidDelims.append(invalidDelim);
+                    }
                     m_validDelims.remove(m_validDelims.length() - 1, 1);
                     lastDelimiterAdded = false;
                 }
-                if (!m_validDelims.contains(ch)) {
-                    m_validDelims.append(ch);
-                    lastDelimiterAdded = true;
-                } else {
-                    lastDelimiterAdded = false;
+
+                // only add delimiters between after first and second section
+                // Some format may have another delimiter after the third
+                // section which we don't care for here (e.g. Hungarian)
+                if (sectionIndex < 3) {
+                    if (!m_validDelims.contains(ch)) {
+                        m_validDelims.append(ch);
+                        lastDelimiterAdded = true;
+                    } else {
+                        lastDelimiterAdded = false;
+                    }
                 }
+
                 if (!lastWasDelimiter) {
                     if (sectionSize > 2) {
                         /// @todo special handling for non-numeric fields
                     }
-                    ++sectionIndex;
-                    sectionSize = 0;
                     lastWasDelimiter = true;
                 }
             }
@@ -106,7 +119,7 @@ public:
         int sectionIndex(0);
 
         for (int idx(0); idx < pos; ++idx) {
-            if (isValidDelimiter(text[idx])) {
+            if (isValidDelimiter(text[idx]) && (sectionIndex < (m_sections.size() - 1))) {
                 ++sectionIndex;
             }
         }
@@ -152,8 +165,11 @@ public:
             const auto ch(text.at(idx));
             if (isValidDelimiter(ch)) {
                 ++partIndex;
-            } else {
+            } else if (!m_invalidDelims.contains(ch) && (partIndex < parts.size())) {
                 parts[partIndex].append(ch);
+            } else {
+                parts.clear();
+                break;
             }
         }
         return parts;
@@ -178,10 +194,18 @@ public:
             return QDate::fromJulianDay(1);
         }
         QVector<QString> parts(editParts());
+        if (parts.isEmpty()) {
+            return {};
+        }
+
         const auto dayIndex = partBySection(QDateTimeEdit::DaySection);
         const auto monthIndex = partBySection(QDateTimeEdit::MonthSection);
         const auto yearIndex = partBySection(QDateTimeEdit::YearSection);
 
+        // make sure we have a valid indeces into the vector
+        if ((dayIndex == -1) || (monthIndex == -1) || (yearIndex == -1))
+            return {};
+
         if (parts.at(dayIndex).isEmpty() || parts.at(monthIndex).isEmpty()) {
             return {};
         }
@@ -403,6 +427,7 @@ public:
 
     KMyMoneyDateEdit* q;
     QVector<QChar> m_validDelims;
+    QVector<QChar> m_invalidDelims;
     QVector<QDateTimeEdit::Section> m_sections;
     int m_originalDay;
     bool m_emptyDateAllowed;
@@ -418,14 +443,20 @@ KMyMoneyDateEdit::KMyMoneyDateEdit(QWidget* parent)
     setOptions(KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker | KDateComboBox::WarnOnInvalid);
 
     connect(lineEdit(), &QLineEdit::textChanged, this, [&](const QString& text) {
-        const auto newDate(d->fixupDate());
-        auto newDateIsValid = newDate.isValid() || (d->m_emptyDateAllowed && text.isEmpty());
-        if (newDateIsValid != d->m_dateValidity) {
-            Q_EMIT dateValidityChanged(newDate);
-            d->m_dateValidity = newDateIsValid;
+        if (!text.isEmpty()) {
+            const auto newDate(d->fixupDate());
+            auto newDateIsValid = newDate.isValid() || (d->m_emptyDateAllowed && text.isEmpty());
+            if (newDateIsValid != d->m_dateValidity) {
+                Q_EMIT dateValidityChanged(newDate);
+                d->m_dateValidity = newDateIsValid;
+            }
         }
     });
 
+    auto optionSettings = options();
+    optionSettings &= ~WarnOnInvalid;
+    setOptions(optionSettings);
+
     setDate(QDate::currentDate());
 }
 
@@ -564,8 +595,9 @@ void KMyMoneyDateEdit::keyPressEvent(QKeyEvent* keyEvent)
 
     case Qt::Key_Plus:
     case Qt::Key_Minus:
+    case Qt::Key_Equal:
         if (isValid()) {
-            d->adjustDate(key == Qt::Key_Plus ? 1 : -1, QDateEdit::NoSection);
+            d->adjustDate(key != Qt::Key_Minus ? 1 : -1, QDateEdit::NoSection);
         }
         break;
 
@@ -619,7 +651,7 @@ void KMyMoneyDateEdit::keyPressEvent(QKeyEvent* keyEvent)
         if (keyEvent->text().length() > 0) {
             const auto ch(keyEvent->text().at(0));
 
-            // prevent two delimters in a row and simply
+            // prevent two delimiters in a row and simply
             // fake an overwrite and select the next section
             if (d->isValidDelimiter(ch)) {
                 if (d->isDelimiterAtPos(pos)) {
