@@ -92,16 +92,18 @@ QSize ibanBicItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QM
     const int margin = style->pixelMetric(QStyle::PM_FocusFrameHMargin) + 1;
 
     // A bic has maximal 11 characters, an IBAN 32
-    return QSize((32 + 11)*metrics.width(QLatin1Char('X')) + 3*margin, 3*metrics.lineSpacing() + metrics.leading() + 2*margin);
+    return QSize((32 + 11) * metrics.horizontalAdvance(QLatin1Char('X')) + 3 * margin, 3 * metrics.lineSpacing() + metrics.leading() + 2 * margin);
 }
 
 QWidget* ibanBicItemDelegate::createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     Q_UNUSED(option);
     ibanBicItemEdit* edit = new ibanBicItemEdit(parent);
-    connect(edit, SIGNAL(commitData(QWidget*)), this, SIGNAL(commitData(QWidget*)));
-    connect(edit, SIGNAL(closeEditor(QWidget*)), this, SIGNAL(closeEditor(QWidget*)));
-    emit sizeHintChanged(index);
+    connect(edit, &ibanBicItemEdit::commitData, this, &ibanBicItemDelegate::commitData);
+    connect(edit, &ibanBicItemEdit::closeEditor, this, [&](QWidget* editor) {
+        Q_EMIT const_cast<ibanBicItemDelegate*>(this)->closeEditor(editor);
+    } );
+    Q_EMIT const_cast<ibanBicItemDelegate*>(this)->sizeHintChanged(index);
     return edit;
 }
 
